/* hfa384x.h: Defines the constants and data structures for the hfa384x
*    --------------------------------------------------------------------
*
*   Linux WLAN 
*
*   The contents of this file are subject to the Mozilla Public
*   License Version 1.0 (the "License"); you may not use this file
*   except in compliance with the License. You may obtain a copy of
*   the License at http://www.mozilla.org/MPL/
*
*   Software distributed under the License is distributed on an "AS
*   IS" basis, WITHOUT WARRANTY OF ANY KIND, either express or
*   implied. See the License for the specific language governing
*   rights and limitations under the License.
*
*   The initial developer of the original code is Mark S. Mathews
*   <mark@absoval.com>.  Portions created by Mark S. Mathews
*   are Copyright (C) 1998 AbsoluteValue Software, Inc.  All
*   Rights Reserved. 
*
*	This software was developed by AbsoluteValue Software, Inc. under
*	contract to Harris Semiconductor.  
*
*   [Change History]
*	990715 - Initial Creation <mark@absoval.com>
*
*	This file contains the constants and data structures for interaction
*	with the hfa384x Wireless LAN (WLAN) Media Access Contoller (MAC).  
*	The hfa384x is a portion of the Harris PRISM(tm) WLAN chipset.
*
*   [Implementation and usage notes]
*
*   [References]
*	CW10 Programmer's Manual v1.5
*	IEEE 802.11 D10.0
*
*    --------------------------------------------------------------------
*/

#ifndef _HFA384x_H
#define _HFA384x_H

/*=============================================================*/
/*------ Constants --------------------------------------------*/

/*--- Mins & Maxs -----------------------------------*/
#define		HFA384x_CMD_ALLOC_LEN_MIN	(4)
#define		HFA384x_CMD_ALLOC_LEN_MAX	(2400)
#define		HFA384x_BAP_DATALEN_MAX		(4096)
#define		HFA384x_BAP_OFFSET_MAX		(4096)
#define		HFA384x_PORTID_MAX		(7)
#define		HFA384x_NUMPORTS_MAX		(HFA384x_PORTID_MAX+1)

/*--- Support Constants -----------------------------*/
#define		HFA384x_BAP_PROC		0
#define		HFA384x_BAP_INT			1

/*--- Register I/O offsets --------------------------*/
#define		HFA384x_CMD_OFF			(0x00)
#define		HFA384x_PARAM0_OFF		(0x02)
#define		HFA384x_PARAM1_OFF		(0x04)
#define		HFA384x_PARAM2_OFF		(0x06)
#define		HFA384x_STATUS_OFF		(0x08)
#define		HFA384x_RESP0_OFF		(0x0A)
#define		HFA384x_RESP1_OFF		(0x0C)
#define		HFA384x_RESP2_OFF		(0x0E)
#define		HFA384x_INFOFID_OFF		(0x10)
#define		HFA384x_RXFID_OFF		(0x20)
#define		HFA384x_ALLOCFID_OFF		(0x22)
#define		HFA384x_TXCOMPLFID_OFF		(0x24)
#define		HFA384x_SELECT0_OFF		(0x18)
#define		HFA384x_OFFSET0_OFF		(0x1C)
#define		HFA384x_DATA0_OFF		(0x36)
#define		HFA384x_SELECT1_OFF		(0x1A)
#define		HFA384x_OFFSET1_OFF		(0x1E)
#define		HFA384x_DATA1_OFF		(0x38)
#define		HFA384x_EVSTAT_OFF		(0x30)
#define		HFA384x_INTEN_OFF		(0x32)
#define		HFA384x_EVACK_OFF		(0x34)
#define		HFA384x_CONTROL_OFF		(0x14)
#define		HFA384x_SWSUPPORT0_OFF		(0x28)
#define		HFA384x_SWSUPPORT1_OFF		(0x2A)
#define		HFA384x_SWSUPPORT2_OFF		(0x2C)
#define		HFA384x_AUXPAGE_OFF		(0x3A)
#define		HFA384x_AUXOFFSET_OFF		(0x3C)
#define		HFA384x_AUXDATA_OFF		(0x3E)

/*--- Register Field Masks --------------------------*/
#define		HFA384x_CMD_BUSY		(BIT15)
#define		HFA384x_CMD_AINFO		(BIT14 | BIT13 | BIT12 | BIT11 | BIT10 | BIT9 | BIT8)
#define		HFA384x_CMD_MACPORT		(BIT10 | BIT9 | BIT8)
#define		HFA384x_CMD_RECL		(BIT8)
#define		HFA384x_CMD_WRITE		(BIT8)
#define		HFA384x_CMD_PROGMODE		(BIT9 | BIT8)
#define		HFA384x_CMD_CMDCODE		(BIT5 | BIT4 | BIT3 | BIT2 | BIT1 | BIT0)

#define		HFA384x_STATUS_RESULT		(BIT14 | BIT13 | BIT12 | BIT11 | BIT10 | BIT9 | BIT8)
#define		HFA384x_STATUS_CMDCODE		(BIT5 | BIT4 | BIT3 | BIT2 | BIT1 | BIT0)

#define		HFA384x_OFFSET_BUSY		(BIT15)
#define		HFA384x_OFFSET_ERR		(BIT14)
#define		HFA384x_OFFSET_DATAOFF		(BIT11 | BIT10 | BIT9 | BIT8 | BIT7 | BIT6 | BIT5 | BIT4 | BIT3 | BIT2 | BIT1)

#define		HFA384x_EVSTAT_TICK		(BIT15)
#define		HFA384x_EVSTAT_WTERR		(BIT14)
#define		HFA384x_EVSTAT_INFDROP		(BIT13)
#define		HFA384x_EVSTAT_INFO		(BIT7)
#define		HFA384x_EVSTAT_CMD		(BIT4)
#define		HFA384x_EVSTAT_ALLOC		(BIT3)
#define		HFA384x_EVSTAT_TXEXC		(BIT2)
#define		HFA384x_EVSTAT_TX		(BIT1)
#define		HFA384x_EVSTAT_RX		(BIT0)

#define		HFA384x_INTEN_TICK		(BIT15)
#define		HFA384x_INTEN_WTERR		(BIT14)
#define		HFA384x_INTEN_INFDROP		(BIT13)
#define		HFA384x_INTEN_INFO		(BIT7)
#define		HFA384x_INTEN_CMD		(BIT4)
#define		HFA384x_INTEN_ALLOC		(BIT3)
#define		HFA384x_INTEN_TXEXC		(BIT2)
#define		HFA384x_INTEN_TX		(BIT1)
#define		HFA384x_INTEN_RX		(BIT0)

#define		HFA384x_EVACK_TICK		(BIT15)
#define		HFA384x_EVACK_WTERR		(BIT14)
#define		HFA384x_EVACK_INFDROP		(BIT13)
#define		HFA384x_EVACK_INFO		(BIT7)
#define		HFA384x_EVACK_CMD		(BIT4)
#define		HFA384x_EVACK_ALLOC		(BIT3)
#define		HFA384x_EVACK_TXEXC		(BIT2)
#define		HFA384x_EVACK_TX		(BIT1)
#define		HFA384x_EVACK_RX		(BIT0)

#define		HFA384x_CONTROL_AUXEN		(BIT15)


/*--- Command Code Constants --------------------------*/
/*--- Controller Commands --------------------------*/
#define		HFA384x_CMDCODE_INIT		0x00
#define		HFA384x_CMDCODE_ENABLE		0x01
#define		HFA384x_CMDCODE_DISABLE		0x02
#define		HFA384x_CMDCODE_DIAG		0x03

/*--- Buffer Mgmt Commands --------------------------*/
#define		HFA384x_CMDCODE_ALLOC		0x0A
#define		HFA384x_CMDCODE_TX		0x0B

/*--- Regulate Commands --------------------------*/
#define		HFA384x_CMDCODE_NOTIFY		0x10
#define		HFA384x_CMDCODE_INQ		0x11

/*--- Configure Commands --------------------------*/
#define		HFA384x_CMDCODE_ACCESS		0x21
#define		HFA384x_CMDCODE_DOWNLD		0x22

/*--- Result Codes --------------------------*/
#define		HFA384x_SUCCESS			(0x00)
#define		HFA384x_CARD_FAIL		(0x01)
#define		HFA384x_NO_BUFF			(0x05)
#define		HFA384x_CMD_ERR			(0x7F)

/*--- Programming Modes --------------------------
	MODE 0: Disable programming
	MODE 1: Enable volatile memory programming
	MODE 2: Enable non-volatile memory programming
	MODE 3: Program non-volatile memory section
--------------------------------------------------*/
#define		HFA384x_PROGMODE_MODE0		(0x00)
#define		HFA384x_PROGMODE_MODE1		(0x01)
#define		HFA384x_PROGMODE_MODE2		(0x02)
#define		HFA384x_PROGMODE_MODE3		(0x03)


/*--- Record ID Constants --------------------------*/
/*--------------------------------------------------------------------
Configuration RIDs: Network Parameters, Static Configuration Entities
--------------------------------------------------------------------*/
#define		HFA384x_RID_CNFPORTTYPE		(0xFC00)
#define		HFA384x_RID_CNFOWNMACADDR	(0xFC01)
#define		HFA384x_RID_CNFDESIREDSSID	(0xFC02)
#define		HFA384x_RID_CNFOWNCHANNEL	(0xFC03)
#define		HFA384x_RID_CNFOWNSSID		(0xFC04)
#define		HFA384x_RID_CNFOWNATIMWIN	(0xFC05)
#define		HFA384x_RID_CNFSYSSCALE		(0xFC06)
#define		HFA384x_RID_CNFMAXDATALEN	(0xFC07)
#define		HFA384x_RID_CNFWDSADDR		(0xFC08)
#define		HFA384x_RID_CNFPMENABLED	(0xFC09)
#define		HFA384x_RID_CNFPMEPS		(0xFC0A)
#define		HFA384x_RID_CNFMULTICASTRX	(0xFC0B)
#define		HFA384x_RID_CNFMAXSLEEPDUR	(0xFC0C)
#define		HFA384x_RID_CNFPMHOLDDUR	(0xFC0D)
#define		HFA384x_RID_CNFOWNNAME		(0xFC0E)
#define		HFA384x_RID_CNFOWNDTIMPER	(0xFC10)
#define		HFA384x_RID_CNFWDSADDR1		(0xFC11)
#define		HFA384x_RID_CNFWDSADDR2		(0xFC12)
#define		HFA384x_RID_CNFWDSADDR3		(0xFC13)
#define		HFA384x_RID_CNFWDSADDR4		(0xFC14)
#define		HFA384x_RID_CNFWDSADDR5		(0xFC15)
#define		HFA384x_RID_CNFWDSADDR6		(0xFC16)
#define		HFA384x_RID_CNFMCASTPMBUFF	(0xFC17)
#define		HFA384x_RID_CNFMAXSLEEPDUR	(0xFC0C)
/*--------------------------------------------------------------------
Configuration RIDs: Network Parameters, Dynamic Configuration Entities
--------------------------------------------------------------------*/
#define		HFA384x_RID_GROUPADDR		(0xFC80)
#define		HFA384x_RID_CREATEIBSS		(0xFC81)
#define		HFA384x_RID_FRAGTHRESH		(0xFC82)
#define		HFA384x_RID_RTSTHRESH		(0xFC83)
#define		HFA384x_RID_TXRATECNTL		(0xFC84)
#define		HFA384x_RID_PROMISCMODE		(0xFC85)
#define		HFA384x_RID_FRAGTHRESH0		(0xFC90)
#define		HFA384x_RID_FRAGTHRESH1		(0xFC91)
#define		HFA384x_RID_FRAGTHRESH2		(0xFC92)
#define		HFA384x_RID_FRAGTHRESH3		(0xFC93)
#define		HFA384x_RID_FRAGTHRESH4		(0xFC94)
#define		HFA384x_RID_FRAGTHRESH5		(0xFC95)
#define		HFA384x_RID_FRAGTHRESH6		(0xFC96)
#define		HFA384x_RID_RTSTHRESH0		(0xFC97)
#define		HFA384x_RID_RTSTHRESH1		(0xFC98)
#define		HFA384x_RID_RTSTHRESH2		(0xFC99)
#define		HFA384x_RID_RTSTHRESH3		(0xFC9A)
#define		HFA384x_RID_RTSTHRESH4		(0xFC9B)
#define		HFA384x_RID_RTSTHRESH5		(0xFC9C)
#define		HFA384x_RID_RTSTHRESH6		(0xFC9D)
#define		HFA384x_RID_TXRATECNTL0		(0xFC9E)
#define		HFA384x_RID_TXRATECNTL1		(0xFC9F)
#define		HFA384x_RID_TXRATECNTL2		(0xFCA0)
#define		HFA384x_RID_TXRATECNTL3		(0xFCA1)
#define		HFA384x_RID_TXRATECNTL4		(0xFCA2)
#define		HFA384x_RID_TXRATECNTL5		(0xFCA3)
#define		HFA384x_RID_TXRATECNTL6		(0xFCA4)
/*--------------------------------------------------------------------
Configuration RIDs: Behavior Parameters
--------------------------------------------------------------------*/
#define		HFA384x_RID_ITICKTIME		(0xFCE0)

/*----------------------------------------------------------------------
Information RIDs: NIC Information
--------------------------------------------------------------------*/
#define		HFA384x_RID_MAXLOADTIME		(0xFD00)
#define		HFA384x_RID_DOWNLOADBUFFER	(0xFD01)
#define		HFA384x_RID_PRIIDENTITY		(0xFD02)
#define		HFA384x_RID_PRISUPRANGE		(0xFD03)
#define		HFA384x_RID_CFIACTRANGES	(0xFD04)
#define		HFA384x_RID_NICSERIALNUMBER	(0xFD0A)
#define		HFA384x_RID_NICIDENTITY		(0xFD0B)
#define		HFA384x_RID_MFISUPRANGE		(0xFD0C)
#define		HFA384x_RID_CFISUPRANGE		(0xFD0D)
#define		HFA384x_RID_CHANNELLIST		(0xFD10)
#define		HFA384x_RID_REGULATORYDOMAINS	(0xFD11)
#define		HFA384x_RID_TEMPTYPE		(0xFD12)
#define		HFA384x_RID_CIS			(0xFD13)
#define		HFA384x_RID_STAIDENTITY		(0xFD20)
#define		HFA384x_RID_STASUPRANGE		(0xFD21)
#define		HFA384x_RID_MFIACTRANGES	(0xFD22)
#define		HFA384x_RID_CFIACTRANGES2	(0xFD23)
/*--------------------------------------------------------------------
Information RIDs:  MAC Information
--------------------------------------------------------------------*/
#define		HFA384x_RID_PORTSTATUS		(0xFD40)
#define		HFA384x_RID_CURRENTSSID		(0xFD41)
#define		HFA384x_RID_CURRENTBSSID	(0xFD42)
#define		HFA384x_RID_COMMSQUALITY	(0xFD43)
#define		HFA384x_RID_CURRENTTXRATE	(0xFD44)
#define		HFA384x_RID_CURRENTBCNINT	(0xFD45)
#define		HFA384x_RID_CURRENTSCALETHRESH	(0xFD46)
#define		HFA384x_RID_PROTOCOLRSPTIME	(0xFD47)
#define		HFA384x_RID_SHORTRETRYLIMIT	(0xFD48)
#define		HFA384x_RID_LONGRETRYLIMIT	(0xFD49)
#define		HFA384x_RID_MAXTXLIFETIME	(0xFD4A)
#define		HFA384x_RID_MAXRXLIFETIME	(0xFD4B)
#define		HFA384x_RID_CFPOLLABLE		(0xFD4C)
#define		HFA384x_RID_AUTHALGORITHMS	(0xFD4D)
#define		HFA384x_RID_PRIVACYOPTIMP	(0xFD4F)
#define		HFA384x_RID_CURRENTTXRATE1	(0xFD80)
#define		HFA384x_RID_CURRENTTXRATE2	(0xFD81)
#define		HFA384x_RID_CURRENTTXRATE3	(0xFD82)
#define		HFA384x_RID_CURRENTTXRATE4	(0xFD83)
#define		HFA384x_RID_CURRENTTXRATE5	(0xFD84)
#define		HFA384x_RID_CURRENTTXRATE6	(0xFD85)
#define		HFA384x_RID_OWNMACADDRESS	(0xFD86)
#define		HFA384x_RID_PCFINFO		(0xFD87)
/*--------------------------------------------------------------------
Information RIDs:  Modem Information
--------------------------------------------------------------------*/
#define		HFA384x_RID_PHYTYPE		(0xFDC0)
#define		HFA384x_RID_CURRENTCHANNEL	(0xFDC1)
#define		HFA384x_RID_CURRENTPOWERSTATE	(0xFDC2)
#define		HFA384x_RID_CCAMODE		(0xFDC3)
#define		HFA384x_RID_SUPPORTEDDATARATES	(0xFDC6)

/*=============================================================*/
/*------ Macros -----------------------------------------------*/

/*--- Register access macros ------------------------*/

#define		HFA384x_CMD(base)		((UINT)(base) + HFA384x_CMD_OFF)
#define		HFA384x_PARAM0(base)		((UINT)(base) + HFA384x_PARAM0_OFF)
#define		HFA384x_PARAM1(base)		((UINT)(base) + HFA384x_PARAM1_OFF)
#define		HFA384x_PARAM2(base)		((UINT)(base) + HFA384x_PARAM2_OFF)
#define		HFA384x_STATUS(base)		((UINT)(base) + HFA384x_STATUS_OFF)
#define		HFA384x_RESP0(base)		((UINT)(base) + HFA384x_RESP0_OFF)
#define		HFA384x_RESP1(base)		((UINT)(base) + HFA384x_RESP1_OFF)
#define		HFA384x_RESP2(base)		((UINT)(base) + HFA384x_RESP2_OFF)
#define		HFA384x_INFOFID(base)		((UINT)(base) + HFA384x_INFOFID_OFF)
#define		HFA384x_RXFID(base)		((UINT)(base) + HFA384x_RXFID_OFF)
#define		HFA384x_ALLOCFID(base)		((UINT)(base) + HFA384x_ALLOCFID_OFF)
#define		HFA384x_TXCOMPLFID(base)	((UINT)(base) + HFA384x_TXCOMPLFID_OFF)
#define		HFA384x_SELECT0(base)		((UINT)(base) + HFA384x_SELECT0_OFF)
#define		HFA384x_OFFSET0(base)		((UINT)(base) + HFA384x_OFFSET0_OFF)
#define		HFA384x_DATA0(base)		((UINT)(base) + HFA384x_DATA0_OFF)
#define		HFA384x_SELECT1(base)		((UINT)(base) + HFA384x_SELECT1_OFF)
#define		HFA384x_OFFSET1(base)		((UINT)(base) + HFA384x_OFFSET1_OFF)
#define		HFA384x_DATA1(base)		((UINT)(base) + HFA384x_DATA1_OFF)
#define		HFA384x_EVSTAT(base)		((UINT)(base) + HFA384x_EVSTAT_OFF)
#define		HFA384x_INTEN(base)		((UINT)(base) + HFA384x_INTEN_OFF)
#define		HFA384x_EVACK(base)		((UINT)(base) + HFA384x_EVACK_OFF)
#define		HFA384x_CONTROL(base)		((UINT)(base) + HFA384x_CONTROL_OFF)
#define		HFA384x_SWSUPPORT0(base)	((UINT)(base) + HFA384x_SWSUPPORT0_OFF)
#define		HFA384x_SWSUPPORT1(base)	((UINT)(base) + HFA384x_SWSUPPORT1_OFF)
#define		HFA384x_SWSUPPORT2(base)	((UINT)(base) + HFA384x_SWSUPPORT2_OFF)


/*--- Register Test/Get/Set Field macros ------------------------*/

#define		HFA384x_CMD_ISBUSY(value)		((UINT)(value) & HFA384x_CMD_BUSY)
#define		HFA384x_CMD_AINFO_GET(value)		(((UINT)(value) & HFA384x_CMD_AINFO) >> 8)
#define		HFA384x_CMD_AINFO_SET(value)		((UINT)(value) << 8)
#define		HFA384x_CMD_MACPORT_GET(value)		((UINT)(HFA384x_CMD_AINFO_GET((UINT)(value) & HFA384x_CMD_MACPORT)))
#define		HFA384x_CMD_MACPORT_SET(value)		(HFA384x_CMD_AINFO_SET(value))
#define		HFA384x_CMD_ISRECL(value)		((UINT)(HFA384x_CMD_AINFO_GET((UINT)(value) & HFA384x_CMD_RECL)))
#define		HFA384x_CMD_RECL_SET(value)		(HFA384x_CMD_AINFO_SET(value))
#define		HFA384x_CMD_ISWRITE(value)		((UINT)(HFA384x_CMD_AINFO_GET((UINT)(value) & HFA384x_CMD_WRITE)))
#define		HFA384x_CMD_WRITE_SET(value)		(HFA384x_CMD_AINFO_SET(value))
#define		HFA384x_CMD_PROGMODE_GET(value)		((UINT)(HFA384x_CMD_AINFO_GET((UINT)(value) & HFA384x_CMD_PROGMODE)))
#define		HFA384x_CMD_PROGMODE_SET(value)		(HFA384x_CMD_AINFO_SET(value))
#define		HFA384x_CMD_CMDCODE_GET(value)		((UINT)(value) & HFA384x_CMD_CMDCODE)
#define		HFA384x_CMD_CMDCODE_SET(value)		((UINT)(value))

#define		HFA384x_STATUS_RESULT_GET(value)	(((UINT)(value) & HFA384x_STATUS_RESULT) >> 8)
#define		HFA384x_STATUS_RESULT_SET(value)	((UINT)(value) << 8)
#define		HFA384x_STATUS_CMDCODE_GET(value)	((UINT)(value) & HFA384x_STATUS_CMDCODE)
#define		HFA384x_STATUS_CMDCODE_SET(value)	((UINT)(value))

#define		HFA384x_OFFSET_ISBUSY(value)		((UINT)(value) & HFA384x_OFFSET_BUSY)
#define		HFA384x_OFFSET_ISERR(value)		((UINT)(value) & HFA384x_OFFSET_ERR)
#define		HFA384x_OFFSET_DATAOFF_GET(value)	((UINT)(value) & HFA384x_OFFSET_DATAOFF)
#define		HFA384x_OFFSET_DATAOFF_SET(value)	((UINT)(value))

#define		HFA384x_EVSTAT_ISTICK(value)		((UINT)(value) & HFA384x_EVSTAT_TICK)
#define		HFA384x_EVSTAT_ISWTERR(value)		((UINT)(value) & HFA384x_EVSTAT_WTERR)
#define		HFA384x_EVSTAT_ISINFDROP(value)		((UINT)(value) & HFA384x_EVSTAT_INFDROP)
#define		HFA384x_EVSTAT_ISINFO(value)		((UINT)(value) & HFA384x_EVSTAT_INFO)
#define		HFA384x_EVSTAT_ISCMD(value)		((UINT)(value) & HFA384x_EVSTAT_CMD)
#define		HFA384x_EVSTAT_ISALLOC(value)		((UINT)(value) & HFA384x_EVSTAT_ALLOC)
#define		HFA384x_EVSTAT_ISTXEXC(value)		((UINT)(value) & HFA384x_EVSTAT_TXEXC)
#define		HFA384x_EVSTAT_ISTX(value)		((UINT)(value) & HFA384x_EVSTAT_TX)
#define		HFA384x_EVSTAT_ISRX(value)		((UINT)(value) & HFA384x_EVSTAT_RX)

#define		HFA384x_INTEN_ISTICK(value)			((UINT)(value) & HFA384x_INTEN_TICK)
#define		HFA384x_INTEN_TICK_SET(value)		((UINT)(value) << 15)
#define		HFA384x_INTEN_ISWTERR(value)		((UINT)(value) & HFA384x_INTEN_WTERR)
#define		HFA384x_INTEN_WTERR_SET(value)		((UINT)(value) << 14)
#define		HFA384x_INTEN_ISINFDROP(value)		((UINT)(value) & HFA384x_INTEN_INFDROP)
#define		HFA384x_INTEN_INFDROP_SET(value)	((UINT)(value) << 13)
#define		HFA384x_INTEN_ISINFO(value)		((UINT)(value) & HFA384x_INTEN_INFO)
#define		HFA384x_INTEN_INFO_SET(value)		((UINT)(value) << 7)
#define		HFA384x_INTEN_ISCMD(value)		((UINT)(value) & HFA384x_INTEN_CMD)
#define		HFA384x_INTEN_CMD_SET(value)		((UINT)(value) << 4)
#define		HFA384x_INTEN_ISALLOC(value)		((UINT)(value) & HFA384x_INTEN_ALLOC)
#define		HFA384x_INTEN_ALLOC_SET(value)		((UINT)(value) << 3)
#define		HFA384x_INTEN_ISTXEXC(value)		((UINT)(value) & HFA384x_INTEN_TXEXC)
#define		HFA384x_INTEN_TXEXC_SET(value)		((UINT)(value) << 2)
#define		HFA384x_INTEN_ISTX(value)		((UINT)(value) & HFA384x_INTEN_TX)
#define		HFA384x_INTEN_TX_SET(value)		((UINT)(value) << 1)
#define		HFA384x_INTEN_ISRX(value)		((UINT)(value) & HFA384x_INTEN_RX)
#define		HFA384x_INTEN_RX_SET(value)		((UINT)(value) << 0)

#define		HFA384x_EVACK_ISTICK(value)		((UINT)(value) & HFA384x_EVACK_TICK)
#define		HFA384x_EVACK_TICK_SET(value)		((UINT)(value) << 15)
#define		HFA384x_EVACK_ISWTERR(value)		((UINT)(value) & HFA384x_EVACK_WTERR)
#define		HFA384x_EVACK_WTERR_SET(value)		((UINT)(value) << 14)
#define		HFA384x_EVACK_ISINFDROP(value)		((UINT)(value) & HFA384x_EVACK_INFDROP)
#define		HFA384x_EVACK_INFDROP_SET(value)	((UINT)(value) << 13)
#define		HFA384x_EVACK_ISINFO(value)		((UINT)(value) & HFA384x_EVACK_INFO)
#define		HFA384x_EVACK_INFO_SET(value)		((UINT)(value) << 7)
#define		HFA384x_EVACK_ISCMD(value)		((UINT)(value) & HFA384x_EVACK_CMD)
#define		HFA384x_EVACK_CMD_SET(value)		((UINT)(value) << 4)
#define		HFA384x_EVACK_ISALLOC(value)		((UINT)(value) & HFA384x_EVACK_ALLOC)
#define		HFA384x_EVACK_ALLOC_SET(value)		((UINT)(value) << 3)
#define		HFA384x_EVACK_ISTXEXC(value)		((UINT)(value) & HFA384x_EVACK_TXEXC)
#define		HFA384x_EVACK_TXEXC_SET(value)		((UINT)(value) << 2)
#define		HFA384x_EVACK_ISTX(value)		((UINT)(value) & HFA384x_EVACK_TX)
#define		HFA384x_EVACK_TX_SET(value)		((UINT)(value) << 1)
#define		HFA384x_EVACK_ISRX(value)		((UINT)(value) & HFA384x_EVACK_RX)
#define		HFA384x_EVACK_RX_SET(value)		((UINT)(value) << 0)

#define		HFA384x_CONTROL_ISAUXEN(value)		((UINT)(value) & HFA384x_CONTROL_AUXEN)

/* Byte Order */
#define hfa384x2host16(val)	(val)
#define hfa384x2host32(val)	(val)
#define host2hfa384x16(val)	(val)
#define host2hfa384x32(val)	(val)

/* Host Maintained State Info */
#define HFA384x_STATE_INIT	1

/*=============================================================*/
/*------ Types and their related constants --------------------*/

/*--------------------------------------------------------------------
Configuration Record Structures:
	Network Parameters, Static Configuration Entities
--------------------------------------------------------------------*/
/* Prototype structure: all configuration record structures start with
these members */

typedef struct hfa384x_record 
{
	UINT16	reclen			__WLAN_ATTRIB_PACK__;
	UINT16	rid			__WLAN_ATTRIB_PACK__;
} hfa384x_rec_t;

typedef struct hfa384x_record16
{
	UINT16	reclen			__WLAN_ATTRIB_PACK__;
	UINT16	rid			__WLAN_ATTRIB_PACK__;
	UINT16	val			__WLAN_ATTRIB_PACK__;
} hfa384x_rec16_t;

/*-- Configuration Record: cnfPortType --*/
typedef struct hfa384x_cnfPortType
{
	UINT16	reclen			__WLAN_ATTRIB_PACK__;
	UINT16	rid			__WLAN_ATTRIB_PACK__;
	UINT16	cnfPortType		__WLAN_ATTRIB_PACK__;
} hfa384x_cnfPortType_t;

/*-- Configuration Record: cnfOwnMACAddress --*/
typedef struct hfa384x_cnfOwnMACAddress
{
	UINT16	reclen			__WLAN_ATTRIB_PACK__;
	UINT16	rid			__WLAN_ATTRIB_PACK__;
	UINT8	cnfOwnMACAddress[6]	__WLAN_ATTRIB_PACK__;
} hfa384x_cnfOwnMACAddress_t;

/*-- Configuration Record: cnfDesiredSSID --*/
typedef struct hfa384x_cnfDesiredSSID
{
	UINT16	reclen			__WLAN_ATTRIB_PACK__;
	UINT16	rid			__WLAN_ATTRIB_PACK__;
	UINT8	cnfDesiredSSID[34]	__WLAN_ATTRIB_PACK__;
} hfa384x_cnfDesiredSSID_t;

/*-- Configuration Record: cnfOwnChannel --*/
typedef struct hfa384x_cnfOwnChannel
{
	UINT16	reclen			__WLAN_ATTRIB_PACK__;
	UINT16	rid			__WLAN_ATTRIB_PACK__;
	UINT16	cnfOwnChannel		__WLAN_ATTRIB_PACK__;
} hfa384x_cnfOwnChannel_t;

/*-- Configuration Record: cnfOwnSSID --*/
typedef struct hfa384x_cnfOwnSSID
{
	UINT16	reclen			__WLAN_ATTRIB_PACK__;
	UINT16	rid			__WLAN_ATTRIB_PACK__;
	UINT8	cnfOwnSSID[34]		__WLAN_ATTRIB_PACK__;
} hfa384x_cnfOwnSSID_t;

/*-- Configuration Record: cnfOwnATIMWindow --*/
typedef struct hfa384x_cnfOwnATIMWindow
{
	UINT16	reclen			__WLAN_ATTRIB_PACK__;
	UINT16	rid			__WLAN_ATTRIB_PACK__;
	UINT16	cnfOwnATIMWindow	__WLAN_ATTRIB_PACK__;
} hfa384x_cnfOwnATIMWindow_t;

/*-- Configuration Record: cnfSystemScale --*/
typedef struct hfa384x_cnfSystemScale
{
	UINT16	reclen			__WLAN_ATTRIB_PACK__;
	UINT16	rid			__WLAN_ATTRIB_PACK__;
	UINT16	cnfSystemScale		__WLAN_ATTRIB_PACK__;
} hfa384x_cnfSystemScale_t;

/*-- Configuration Record: cnfMaxDataLength --*/
typedef struct hfa384x_cnfMaxDataLength
{
	UINT16	reclen			__WLAN_ATTRIB_PACK__;
	UINT16	rid			__WLAN_ATTRIB_PACK__;
	UINT16	cnfMaxDataLength	__WLAN_ATTRIB_PACK__;
} hfa384x_cnfMaxDataLength_t;

/*-- Configuration Record: cnfWDSAddress --*/
typedef struct hfa384x_cnfWDSAddress
{
	UINT16	reclen			__WLAN_ATTRIB_PACK__;
	UINT16	rid			__WLAN_ATTRIB_PACK__;
	UINT8	cnfWDSAddress[6]	__WLAN_ATTRIB_PACK__;
} hfa384x_cnfWDSAddress_t;

/*-- Configuration Record: cnfPMEnabled --*/
typedef struct hfa384x_cnfPMEnabled
{
	UINT16	reclen			__WLAN_ATTRIB_PACK__;
	UINT16	rid			__WLAN_ATTRIB_PACK__;
	UINT16	cnfPMEnabled		__WLAN_ATTRIB_PACK__;
} hfa384x_cnfPMEnabled_t;

/*-- Configuration Record: cnfPMEPS --*/
typedef struct hfa384x_cnfPMEPS
{
	UINT16	reclen			__WLAN_ATTRIB_PACK__;
	UINT16	rid			__WLAN_ATTRIB_PACK__;
	UINT16	cnfPMEPS		__WLAN_ATTRIB_PACK__;
} hfa384x_cnfPMEPS_t;

/*-- Configuration Record: cnfMulticastReceive --*/
typedef struct hfa384x_cnfMulticastReceive
{
	UINT16	reclen			__WLAN_ATTRIB_PACK__;
	UINT16	rid			__WLAN_ATTRIB_PACK__;
	UINT16	cnfMulticastReceive	__WLAN_ATTRIB_PACK__;
} hfa384x_cnfMulticastReceive_t;

/*-- Configuration Record: cnfMaxSleepDuration --*/
typedef struct hfa384x_cnfMaxSleepDuration
{
	UINT16	reclen			__WLAN_ATTRIB_PACK__;
	UINT16	rid			__WLAN_ATTRIB_PACK__;
	UINT16	cnfMaxSleepDuration	__WLAN_ATTRIB_PACK__;
} hfa384x_cnfMaxSleepDuration_t;

/*-- Configuration Record: cnfPMHoldoverDuration --*/
typedef struct hfa384x_cnfPMHoldoverDuration
{
	UINT16	reclen			__WLAN_ATTRIB_PACK__;
	UINT16	rid			__WLAN_ATTRIB_PACK__;
	UINT16	cnfPMHoldoverDuration	__WLAN_ATTRIB_PACK__;
} hfa384x_cnfPMHoldoverDuration_t;

/*-- Configuration Record: cnfOwnName --*/
typedef struct hfa384x_cnfOwnName
{
	UINT16	reclen			__WLAN_ATTRIB_PACK__;
	UINT16	rid			__WLAN_ATTRIB_PACK__;
	UINT8	cnfOwnName[34]		__WLAN_ATTRIB_PACK__;
} hfa384x_cnfOwnName_t;

/*-- Configuration Record: cnfOwnDTIMPeriod --*/
typedef struct hfa384x_cnfOwnDTIMPeriod
{
	UINT16	reclen			__WLAN_ATTRIB_PACK__;
	UINT16	rid			__WLAN_ATTRIB_PACK__;
	UINT16	cnfOwnDTIMPeriod	__WLAN_ATTRIB_PACK__;
} hfa384x_cnfOwnDTIMPeriod_t;

/*-- Configuration Record: cnfWDSAddress --*/
typedef struct hfa384x_cnfWDSAddressN
{
	UINT16	reclen			__WLAN_ATTRIB_PACK__;
	UINT16	rid			__WLAN_ATTRIB_PACK__;
	UINT8	cnfWDSAddress[6]	__WLAN_ATTRIB_PACK__;
} hfa384x_cnfWDSAddressN_t;

/*-- Configuration Record: cnfMulticastPMBuffering --*/
typedef struct hfa384x_cnfMulticastPMBuffering
{
	UINT16	reclen			__WLAN_ATTRIB_PACK__;
	UINT16	rid			__WLAN_ATTRIB_PACK__;
	UINT16	cnfMulticastPMBuffering	__WLAN_ATTRIB_PACK__;
} hfa384x_cnfMulticastPMBuffering_t;

/*--------------------------------------------------------------------
Configuration Record Structures:
	Network Parameters, Dynamic Configuration Entities
--------------------------------------------------------------------*/

/*-- Configuration Record: GroupAddresses --*/
typedef struct hfa384x_GroupAddresses
{
	UINT16	reclen			__WLAN_ATTRIB_PACK__;
	UINT16	rid			__WLAN_ATTRIB_PACK__;
	UINT8	MACAddress[16][6]	__WLAN_ATTRIB_PACK__;
} hfa384x_GroupAddresses_t;

/*-- Configuration Record: CreateIBSS --*/
typedef struct hfa384x_CreateIBSS
{
	UINT16	reclen			__WLAN_ATTRIB_PACK__;
	UINT16	rid			__WLAN_ATTRIB_PACK__;
	UINT16	CreateIBSS		__WLAN_ATTRIB_PACK__;
} hfa384x_CreateIBSS_t;

/*-- Configuration Record: FragmentationThreshold --*/
typedef struct hfa384x_FragmentationThreshold
{
	UINT16	reclen			__WLAN_ATTRIB_PACK__;
	UINT16	rid			__WLAN_ATTRIB_PACK__;
	UINT16	FragmentationThreshold	__WLAN_ATTRIB_PACK__;
} hfa384x_FragmentationThreshold_t;

/*-- Configuration Record: RTSThreshold --*/
typedef struct hfa384x_RTSThreshold
{
	UINT16	reclen			__WLAN_ATTRIB_PACK__;
	UINT16	rid			__WLAN_ATTRIB_PACK__;
	UINT16	RTSThreshold		__WLAN_ATTRIB_PACK__;
} hfa384x_RTSThreshold_t;

/*-- Configuration Record: TxRateControl --*/
typedef struct hfa384x_TxRateControl
{
	UINT16	reclen			__WLAN_ATTRIB_PACK__;
	UINT16	rid			__WLAN_ATTRIB_PACK__;
	UINT16	TxRateControl		__WLAN_ATTRIB_PACK__;
} hfa384x_TxRateControl_t;

/*-- Configuration Record: PromiscuousMode --*/
typedef struct hfa384x_PromiscuousMode
{
	UINT16	reclen			__WLAN_ATTRIB_PACK__;
	UINT16	rid			__WLAN_ATTRIB_PACK__;
	UINT16	PromiscuousMode		__WLAN_ATTRIB_PACK__;
} hfa384x_PromiscuousMode_t;

/*--------------------------------------------------------------------
Configuration Record Structures: Behavior Parameters
--------------------------------------------------------------------*/

/*-- Configuration Record: TickTime --*/
typedef struct hfa384x_TickTime
{
	UINT16	reclen			__WLAN_ATTRIB_PACK__;
	UINT16	rid			__WLAN_ATTRIB_PACK__;
	UINT16	TickTime		__WLAN_ATTRIB_PACK__;
} hfa384x_TickTime_t;

/*--------------------------------------------------------------------
Information Record Structures: NIC Information
--------------------------------------------------------------------*/

/*-- Information Record: MaxLoadTime --*/
typedef struct hfa384x_MaxLoadTime
{
	UINT16	reclen			__WLAN_ATTRIB_PACK__;
	UINT16	rid			__WLAN_ATTRIB_PACK__;
	UINT16	MaxLoadTime		__WLAN_ATTRIB_PACK__;
} hfa384x_MaxLoadTime_t;

/*-- Information Record: DownLoadBuffer --*/
typedef struct hfa384x_DownLoadBuffer
{
	UINT16	reclen			__WLAN_ATTRIB_PACK__;
	UINT16	rid			__WLAN_ATTRIB_PACK__;
	UINT16	DownLoadBufferPage	__WLAN_ATTRIB_PACK__;
	UINT16	DownLoadBufferOffset	__WLAN_ATTRIB_PACK__;
	UINT16	DownLoadBufferLength	__WLAN_ATTRIB_PACK__;
} hfa384x_DownLoadBuffer_t;

/*-- Information Record: PRIIdentity --*/
typedef struct hfa384x_PRIIdentity
{
	UINT16	reclen			__WLAN_ATTRIB_PACK__;
	UINT16	rid			__WLAN_ATTRIB_PACK__;
	UINT16	PRICompID		__WLAN_ATTRIB_PACK__;
	UINT16	PRIVariant		__WLAN_ATTRIB_PACK__;
	UINT16	PRIMajorVersion		__WLAN_ATTRIB_PACK__;
	UINT16	PRIMinorVersion		__WLAN_ATTRIB_PACK__;
} hfa384x_PRIIdentity_t;

/*-- Information Record: PRISupRange --*/
typedef struct hfa384x_PRISupRange
{
	UINT16	reclen			__WLAN_ATTRIB_PACK__;
	UINT16	rid			__WLAN_ATTRIB_PACK__;
	UINT16	PRIRole			__WLAN_ATTRIB_PACK__;
	UINT16	PRIID			__WLAN_ATTRIB_PACK__;
	UINT16	PRIVariant		__WLAN_ATTRIB_PACK__;
	UINT16	PRIBottom		__WLAN_ATTRIB_PACK__;
	UINT16	PRITop			__WLAN_ATTRIB_PACK__;
} hfa384x_PRISupRange_t;

/*-- Information Record: CFIActRanges --*/
typedef struct hfa384x_CFIActRanges
{
	UINT16	reclen			__WLAN_ATTRIB_PACK__;
	UINT16	rid			__WLAN_ATTRIB_PACK__;
	UINT16	CFIRole			__WLAN_ATTRIB_PACK__;
	UINT16	CFIID			__WLAN_ATTRIB_PACK__;
	UINT16	CFIVariant		__WLAN_ATTRIB_PACK__;
	UINT16	CFIBottom		__WLAN_ATTRIB_PACK__;
	UINT16	CFITop			__WLAN_ATTRIB_PACK__;
} hfa384x_CFIActRanges_t;

/*-- Information Record: NICSerialNumber --*/
typedef struct hfa384x_NICSerialNumber
{
	UINT16	reclen			__WLAN_ATTRIB_PACK__;
	UINT16	rid			__WLAN_ATTRIB_PACK__;
	UINT8	NICSerialNumber[12]	__WLAN_ATTRIB_PACK__;
} hfa384x_NICSerialNumber_t;

/*-- Information Record: NICIdentity --*/
typedef struct hfa384x_NICIdentity
{
	UINT16	reclen			__WLAN_ATTRIB_PACK__;
	UINT16	rid			__WLAN_ATTRIB_PACK__;
	UINT16	NICCompID		__WLAN_ATTRIB_PACK__;
	UINT16	NICVariant		__WLAN_ATTRIB_PACK__;
	UINT16	NICMajorVersion		__WLAN_ATTRIB_PACK__;
	UINT16	NICMinorVersion		__WLAN_ATTRIB_PACK__;
} hfa384x_NICIdentity_t;

/*-- Information Record: MFISupRange --*/
typedef struct hfa384x_MFISupRange
{
	UINT16	reclen			__WLAN_ATTRIB_PACK__;
	UINT16	rid			__WLAN_ATTRIB_PACK__;
	UINT16	MFIRole			__WLAN_ATTRIB_PACK__;
	UINT16	MFIID			__WLAN_ATTRIB_PACK__;
	UINT16	MFIVariant		__WLAN_ATTRIB_PACK__;
	UINT16	MFIBottom		__WLAN_ATTRIB_PACK__;
	UINT16	MFITop			__WLAN_ATTRIB_PACK__;
} hfa384x_MFISupRange_t;

/*-- Information Record: CFISupRange --*/
typedef struct hfa384x_CFISupRange
{
	UINT16	reclen			__WLAN_ATTRIB_PACK__;
	UINT16	rid			__WLAN_ATTRIB_PACK__;
	UINT16	CFIRole			__WLAN_ATTRIB_PACK__;
	UINT16	CFIID			__WLAN_ATTRIB_PACK__;
	UINT16	CFIVariant		__WLAN_ATTRIB_PACK__;
	UINT16	CFIBottom		__WLAN_ATTRIB_PACK__;
	UINT16	CFITop			__WLAN_ATTRIB_PACK__;
} hfa384x_CFISupRange_t;

/*-- Information Record: ChannelList --*/
typedef struct hfa384x_ChannelList
{
	UINT16	reclen			__WLAN_ATTRIB_PACK__;
	UINT16	rid			__WLAN_ATTRIB_PACK__;
	UINT16	ChannelList		__WLAN_ATTRIB_PACK__;
} hfa384x_ChannelList_t;

/*-- Information Record: RegulatoryDomains --*/
typedef struct hfa384x_RegulatoryDomains
{
	UINT16	reclen			__WLAN_ATTRIB_PACK__;
	UINT16	rid			__WLAN_ATTRIB_PACK__;
	UINT8	RegulatoryDomains[12]	__WLAN_ATTRIB_PACK__;
} hfa384x_RegulatoryDomains_t;

/*-- Information Record: TempType --*/
typedef struct hfa384x_TempType
{
	UINT16	reclen			__WLAN_ATTRIB_PACK__;
	UINT16	rid			__WLAN_ATTRIB_PACK__;
	UINT16	TempType		__WLAN_ATTRIB_PACK__;
} hfa384x_TempType_t;

/*-- Information Record: CIS --*/
typedef struct hfa384x_CIS
{
	UINT16	reclen			__WLAN_ATTRIB_PACK__;
	UINT16	rid			__WLAN_ATTRIB_PACK__;
	UINT8	CIS[480]		__WLAN_ATTRIB_PACK__;
} hfa384x_CIS_t;

/*-- Information Record: STAIdentity --*/
typedef struct hfa384x_STAIdentity
{
	UINT16	reclen			__WLAN_ATTRIB_PACK__;
	UINT16	rid			__WLAN_ATTRIB_PACK__;
	UINT16	STACompID		__WLAN_ATTRIB_PACK__;
	UINT16	STAVariant		__WLAN_ATTRIB_PACK__;
	UINT16	STAMajorVersion		__WLAN_ATTRIB_PACK__;
	UINT16	STAMinorVersion		__WLAN_ATTRIB_PACK__;
} hfa384x_STAIdentity_t;

/*-- Information Record: STASupRange --*/
typedef struct hfa384x_STASupRange
{
	UINT16	reclen			__WLAN_ATTRIB_PACK__;
	UINT16	rid			__WLAN_ATTRIB_PACK__;
	UINT16	STARole			__WLAN_ATTRIB_PACK__;
	UINT16	STAID			__WLAN_ATTRIB_PACK__;
	UINT16	STAVariant		__WLAN_ATTRIB_PACK__;
	UINT16	STABottom		__WLAN_ATTRIB_PACK__;
	UINT16	STATop			__WLAN_ATTRIB_PACK__;
} hfa384x_STASupRange_t;

/*-- Information Record: MFIActRanges --*/
typedef struct hfa384x_MFIActRanges
{
	UINT16	reclen			__WLAN_ATTRIB_PACK__;
	UINT16	rid			__WLAN_ATTRIB_PACK__;
	UINT16	MFIRole			__WLAN_ATTRIB_PACK__;
	UINT16	MFIID			__WLAN_ATTRIB_PACK__;
	UINT16	MFIVariant		__WLAN_ATTRIB_PACK__;
	UINT16	MFIBottom		__WLAN_ATTRIB_PACK__;
	UINT16	MFITop			__WLAN_ATTRIB_PACK__;
} hfa384x_MFIActRanges_t;

/*--------------------------------------------------------------------
Information Record Structures: NIC Information
--------------------------------------------------------------------*/

/*-- Information Record: PortStatus --*/
typedef struct hfa384x_PortStatus
{
	UINT16	reclen			__WLAN_ATTRIB_PACK__;
	UINT16	rid			__WLAN_ATTRIB_PACK__;
	UINT16	PortStatus		__WLAN_ATTRIB_PACK__;
} hfa384x_PortStatus_t;

#define HFA384x_PSTATUS_DISABLED	1
#define HFA384x_PSTATUS_SEARCHING	2
#define HFA384x_PSTATUS_CONN_IBSS	3
#define HFA384x_PSTATUS_CONN_ESS	4
#define HFA384x_PSTATUS_OUTOFRANGE	5
#define HFA384x_PSTATUS_CONN_WDS	6

/*-- Information Record: CurrentSSID --*/
typedef struct hfa384x_CurrentSSID
{
	UINT16	reclen			__WLAN_ATTRIB_PACK__;
	UINT16	rid			__WLAN_ATTRIB_PACK__;
	UINT8	CurrentSSID[34]		__WLAN_ATTRIB_PACK__;
} hfa384x_CurrentSSID_t;

/*-- Information Record: CurrentBSSID --*/
typedef struct hfa384x_CurrentBSSID
{
	UINT16	reclen			__WLAN_ATTRIB_PACK__;
	UINT16	rid			__WLAN_ATTRIB_PACK__;
	UINT8	CurrentBSSID[6]		__WLAN_ATTRIB_PACK__;
} hfa384x_CurrentBSSID_t;

/*-- Information Record: CommsQuality --*/
typedef struct hfa384x_CommsQuality
{
	UINT16	reclen			__WLAN_ATTRIB_PACK__;
	UINT16	rid			__WLAN_ATTRIB_PACK__;
	UINT16	CQ_currBSS		__WLAN_ATTRIB_PACK__;
	UINT16	ASL_currBSS		__WLAN_ATTRIB_PACK__;
	UINT16	ANL_currFC		__WLAN_ATTRIB_PACK__;
} hfa384x_CommsQuality_t;

/*-- Information Record: CurrentTxRate --*/
typedef struct hfa384x_CurrentTxRate
{
	UINT16	reclen			__WLAN_ATTRIB_PACK__;
	UINT16	rid			__WLAN_ATTRIB_PACK__;
	UINT16	CurrentTxRate		__WLAN_ATTRIB_PACK__;
} hfa384x_CurrentTxRate_t;

/*-- Information Record: CurrentBeaconInterval --*/
typedef struct hfa384x_CurrentBeaconInterval
{
	UINT16	reclen			__WLAN_ATTRIB_PACK__;
	UINT16	rid			__WLAN_ATTRIB_PACK__;
	UINT16	CurrentBeaconInterval	__WLAN_ATTRIB_PACK__;
} hfa384x_CurrentBeaconInterval_t;

/*-- Information Record: CurrentScaleThresholds --*/
typedef struct hfa384x_CurrentScaleThresholds
{
	UINT16	reclen			__WLAN_ATTRIB_PACK__;
	UINT16	rid			__WLAN_ATTRIB_PACK__;
	UINT16	EnergyDetectThreshold	__WLAN_ATTRIB_PACK__;
	UINT16	CarrierDetectThreshold	__WLAN_ATTRIB_PACK__;
	UINT16	DeferDetectThreshold	__WLAN_ATTRIB_PACK__;
	UINT16	CellSearchThreshold	__WLAN_ATTRIB_PACK__; /* Stations only */
	UINT16	DeadSpotThreshold	__WLAN_ATTRIB_PACK__; /* Stations only */
} hfa384x_CurrentScaleThresholds_t;

/*-- Information Record: ProtocolRspTime --*/
typedef struct hfa384x_ProtocolRspTime
{
	UINT16	reclen			__WLAN_ATTRIB_PACK__;
	UINT16	rid			__WLAN_ATTRIB_PACK__;
	UINT16	ProtocolRspTime		__WLAN_ATTRIB_PACK__;
} hfa384x_ProtocolRspTime_t;

/*-- Information Record: ShortRetryLimit --*/
typedef struct hfa384x_ShortRetryLimit
{
	UINT16	reclen			__WLAN_ATTRIB_PACK__;
	UINT16	rid			__WLAN_ATTRIB_PACK__;
	UINT16	ShortRetryLimit		__WLAN_ATTRIB_PACK__;
} hfa384x_ShortRetryLimit_t;

/*-- Information Record: LongRetryLimit --*/
typedef struct hfa384x_LongRetryLimit
{
	UINT16	reclen			__WLAN_ATTRIB_PACK__;
	UINT16	rid			__WLAN_ATTRIB_PACK__;
	UINT16	LongRetryLimit		__WLAN_ATTRIB_PACK__;
} hfa384x_LongRetryLimit_t;

/*-- Information Record: MaxTransmitLifetime --*/
typedef struct hfa384x_MaxTransmitLifetime
{
	UINT16	reclen			__WLAN_ATTRIB_PACK__;
	UINT16	rid			__WLAN_ATTRIB_PACK__;
	UINT16	MaxTransmitLifetime	__WLAN_ATTRIB_PACK__;
} hfa384x_MaxTransmitLifetime_t;

/*-- Information Record: MaxReceiveLifetime --*/
typedef struct hfa384x_MaxReceiveLifetime
{
	UINT16	reclen			__WLAN_ATTRIB_PACK__;
	UINT16	rid			__WLAN_ATTRIB_PACK__;
	UINT16	MaxReceiveLifetime	__WLAN_ATTRIB_PACK__;
} hfa384x_MaxReceiveLifetime_t;

/*-- Information Record: CFPollable --*/
typedef struct hfa384x_CFPollable
{
	UINT16	reclen			__WLAN_ATTRIB_PACK__;
	UINT16	rid			__WLAN_ATTRIB_PACK__;
	UINT16	CFPollable		__WLAN_ATTRIB_PACK__;
} hfa384x_CFPollable_t;

/*-- Information Record: AuthenticationAlgorithms --*/
typedef struct hfa384x_AuthenticationAlgorithms
{
	UINT16	reclen			__WLAN_ATTRIB_PACK__;
	UINT16	rid			__WLAN_ATTRIB_PACK__;
	UINT16	AuthenticationType	__WLAN_ATTRIB_PACK__;
	UINT16	TypeEnabled		__WLAN_ATTRIB_PACK__;
} hfa384x_AuthenticationAlgorithms_t;

/*-- Information Record: PrivacyOptionImplemented --*/
typedef struct hfa384x_PrivacyOptionImplemented
{
	UINT16	reclen			__WLAN_ATTRIB_PACK__;
	UINT16	rid			__WLAN_ATTRIB_PACK__;
	UINT16	PrivacyOptionImplemented	__WLAN_ATTRIB_PACK__;
} hfa384x_PrivacyOptionImplemented_t;

/*-- Information Record: OwnMACAddress --*/
typedef struct hfa384x_OwnMACAddress
{
	UINT16	reclen			__WLAN_ATTRIB_PACK__;
	UINT16	rid			__WLAN_ATTRIB_PACK__;
	UINT8	OwnMACAddress[6]	__WLAN_ATTRIB_PACK__;
} hfa384x_OwnMACAddress_t;

/*-- Information Record: PCFInfo --*/
typedef struct hfa384x_PCFInfo
{
	UINT16	reclen			__WLAN_ATTRIB_PACK__;
	UINT16	rid			__WLAN_ATTRIB_PACK__;
	UINT16	MediumOccupancyLimit	__WLAN_ATTRIB_PACK__;
	UINT16	CFPPeriod		__WLAN_ATTRIB_PACK__;
	UINT16	CFPMaxDuration		__WLAN_ATTRIB_PACK__;
} hfa384x_PCFInfo_t;

/*--------------------------------------------------------------------
Information Record Structures: Modem Information Records 
--------------------------------------------------------------------*/

/*-- Information Record: PHYType --*/
typedef struct hfa384x_PHYType
{
	UINT16	reclen			__WLAN_ATTRIB_PACK__;
	UINT16	rid			__WLAN_ATTRIB_PACK__;
	UINT16	PHYType			__WLAN_ATTRIB_PACK__;
} hfa384x_PHYType_t;

/*-- Information Record: CurrentChannel --*/
typedef struct hfa384x_CurrentChannel
{
	UINT16	reclen			__WLAN_ATTRIB_PACK__;
	UINT16	rid			__WLAN_ATTRIB_PACK__;
	UINT16	CurrentChannel		__WLAN_ATTRIB_PACK__;
} hfa384x_CurrentChannel_t;

/*-- Information Record: CurrentPowerState --*/
typedef struct hfa384x_CurrentPowerState
{
	UINT16	reclen			__WLAN_ATTRIB_PACK__;
	UINT16	rid			__WLAN_ATTRIB_PACK__;
	UINT16	CurrentPowerState	__WLAN_ATTRIB_PACK__;
} hfa384x_CurrentPowerState_t;

/*-- Information Record: CCAMode --*/
typedef struct hfa384x_CCAMode
{
	UINT16	reclen			__WLAN_ATTRIB_PACK__;
	UINT16	rid			__WLAN_ATTRIB_PACK__;
	UINT16	CCAMode			__WLAN_ATTRIB_PACK__;
} hfa384x_CCAMode_t;

/*-- Information Record: SupportedDataRates --*/
typedef struct hfa384x_SupportedDataRates
{
	UINT16	reclen			__WLAN_ATTRIB_PACK__;
	UINT16	rid			__WLAN_ATTRIB_PACK__;
	UINT8	SupportedDataRates[10]	__WLAN_ATTRIB_PACK__;
} hfa384x_SupportedDataRates_t;

/*--------------------------------------------------------------------
                 FRAME DESCRIPTORS AND FRAME STRUCTURES

FRAME DESCRIPTORS: Offsets

----------------------------------------------------------------------
Control Info (offset 44-51)
--------------------------------------------------------------------*/
#define		HFA384x_FD_STATUS_OFF			(0x44)
#define		HFA384x_FD_TIME_OFF			(0x46)
#define		HFA384x_FD_SWSUPPORT_OFF		(0x4A)
#define		HFA384x_FD_SILENCE_OFF			(0x4A)
#define		HFA384x_FD_SIGNAL_OFF			(0x4B)
#define		HFA384x_FD_RATE_OFF			(0x4C)
#define		HFA384x_FD_RXFLOW_OFF			(0x4D)
#define		HFA384x_FD_RESERVED_OFF			(0x4E)
#define		HFA384x_FD_TXCONTROL_OFF		(0x50)
/*--------------------------------------------------------------------
802.11 Header (offset 52-6B)
--------------------------------------------------------------------*/
#define		HFA384x_FD_FRAMECONTROL_OFF		(0x52)
#define		HFA384x_FD_DURATIONID_OFF		(0x54)
#define		HFA384x_FD_ADDRESS1_OFF			(0x56)
#define		HFA384x_FD_ADDRESS2_OFF			(0x5C)
#define		HFA384x_FD_ADDRESS3_OFF			(0x62)
#define		HFA384x_FD_SEQCONTROL_OFF		(0x68)
#define		HFA384x_FD_ADDRESS4_OFF			(0x6A)
#define		HFA384x_FD_DATALEN_OFF			(0x70) 
/*--------------------------------------------------------------------
802.3 Header (offset 72-7F)
--------------------------------------------------------------------*/
#define		HFA384x_FD_DESTADDRESS_OFF		(0x72)
#define		HFA384x_FD_SRCADDRESS_OFF		(0x78)
#define		HFA384x_FD_DATALENGTH_OFF		(0x7E)

/*--------------------------------------------------------------------
FRAME STRUCTURES: Communication Frames
----------------------------------------------------------------------
Communication Frames: Transmit Frames
--------------------------------------------------------------------*/
/*-- Communication Frame: Transmit Frame Structure --*/
typedef struct hfa384x_tx_frame
{
	UINT16	status			__WLAN_ATTRIB_PACK__;
	UINT16	reserved1		__WLAN_ATTRIB_PACK__;
	UINT16	reserved2		__WLAN_ATTRIB_PACK__;
	UINT32	sw_support		__WLAN_ATTRIB_PACK__;
	UINT16	reserved3		__WLAN_ATTRIB_PACK__;
	UINT16	tx_control		__WLAN_ATTRIB_PACK__;

	/*-- 802.11 Header Information --*/

	UINT16	frame_control		__WLAN_ATTRIB_PACK__;
	UINT16	duration_id		__WLAN_ATTRIB_PACK__;
	UINT8	address1[6]		__WLAN_ATTRIB_PACK__;
	UINT8	address2[6]		__WLAN_ATTRIB_PACK__;
	UINT8	address3[6]		__WLAN_ATTRIB_PACK__;
	UINT16	sequence_control	__WLAN_ATTRIB_PACK__;
	UINT8	address4[6]		__WLAN_ATTRIB_PACK__;
	UINT16	data_len		__WLAN_ATTRIB_PACK__; /* little endian format */

	/*-- 802.3 Header Information --*/

	UINT8	dest_addr[6]		__WLAN_ATTRIB_PACK__;
	UINT8	src_addr[6]		__WLAN_ATTRIB_PACK__;
	UINT16	data_length		__WLAN_ATTRIB_PACK__; /* big endian format */
} hfa384x_tx_frame_t;
/*--------------------------------------------------------------------
Communication Frames: Field Masks for Transmit Frames
--------------------------------------------------------------------*/
/*-- Status Field --*/
#define		HFA384x_TXSTATUS_FORMERR		(BIT3)
#define		HFA384x_TXSTATUS_DISCON			(BIT2)
#define		HFA384x_TXSTATUS_AGEDERR		(BIT1)
#define		HFA384x_TXSTATUS_RETRYERR		(BIT0)
/*-- Transmit Control Field --*/
#define		HFA384x_TX_MACPORT			(BIT10 | BIT9 | BIT8)
#define		HFA384x_TX_STRUCTYPE			(BIT4 | BIT3)
#define		HFA384x_TX_TXEX				(BIT2)
#define		HFA384x_TX_TXOK				(BIT1)
/*--------------------------------------------------------------------
Communication Frames: Test/Get/Set Field Values for Transmit Frames
--------------------------------------------------------------------*/
/*-- Status Field --*/
#define		HFA384x_TXSTATUS_ISFORMERR(value)	((UINT)(value) & HFA384x_TXSTATUS_FORMERR)
#define		HFA384x_TXSTATUS_ISDISCON(value)	((UINT)(value) & HFA384x_TXSTATUS_DISCON)
#define		HFA384x_TXSTATUS_ISAGEDERR(value)	((UINT)(value) & HFA384x_TXSTATUS_AGEDERR)
#define		HFA384x_TXSTATUS_ISRETRYERR(value)	((UINT)(value) & HFA384x_TXSTATUS_RETRYERR)
#define		HFA384x_TX_MACPORT_GET(value)		(((UINT)(value) & HFA384x_TX_MACPORT) >> 8)
#define		HFA384x_TX_MACPORT_SET(value)		((UINT)(value) << 8)
#define		HFA384x_TX_STRUCTYPE_GET(value)		(((UINT)(value) & HFA384x_TX_STRUCTYPE) >> 3)
#define		HFA384x_TX_STRUCTYPE_SET(value)		((UINT)(value) << 3)
#define		HFA384x_TX_TXEX_GET(value)		((UINT)(value) & HFA384x_TX_TXEX)
#define		HFA384x_TX_TXEX_SET(value)		((UINT)(value) << 2)
#define		HFA384x_TX_TXOK_GET(value)		((UINT)(value) & HFA384x_TX_TXOK)
#define		HFA384x_TX_TXOK_SET(value)		((UINT)(value) << 1)
/*--------------------------------------------------------------------
Communication Frames: Receive Frames
--------------------------------------------------------------------*/
/*-- Communication Frame: Receive Frame Structure --*/
typedef struct hfa384x_rx_frame
{
	UINT16	status			__WLAN_ATTRIB_PACK__;
	UINT32	time			__WLAN_ATTRIB_PACK__;
	UINT8	signal			__WLAN_ATTRIB_PACK__;
	UINT8	silence			__WLAN_ATTRIB_PACK__;
	UINT8	rx_flow			__WLAN_ATTRIB_PACK__;
	UINT8	rate			__WLAN_ATTRIB_PACK__;
	UINT16	reserved1		__WLAN_ATTRIB_PACK__;
	UINT16	reserved2		__WLAN_ATTRIB_PACK__;

	/*-- 802.11 Header Information --*/

	UINT16	frame_control		__WLAN_ATTRIB_PACK__;
	UINT16	duration_id		__WLAN_ATTRIB_PACK__;
	UINT8	address1[6]		__WLAN_ATTRIB_PACK__;
	UINT8	address2[6]		__WLAN_ATTRIB_PACK__;
	UINT8	address3[6]		__WLAN_ATTRIB_PACK__;
	UINT16	sequence_control	__WLAN_ATTRIB_PACK__;
	UINT8	address4[6]		__WLAN_ATTRIB_PACK__;
	UINT16	data_len		__WLAN_ATTRIB_PACK__; /* little endian format */

	/*-- 802.3 Header Information --*/

	UINT8	dest_addr[6]		__WLAN_ATTRIB_PACK__;
	UINT8	src_addr[6]		__WLAN_ATTRIB_PACK__;
	UINT16	data_length		__WLAN_ATTRIB_PACK__; /* big endian format */
} hfa384x_rx_frame_t;
/*--------------------------------------------------------------------
Communication Frames: Field Masks for Receive Frames
--------------------------------------------------------------------*/
/*-- Offsets --------*/
#define		HFA384x_RX_DATA_LEN_OFF			44
#define		HFA384x_RX_80211HDR_OFF			14
#define		HFA384x_RX_DATA_OFF			60

/*-- Status Fields --*/
#define		HFA384x_RXSTATUS_MSGTYPE		(BIT15 | BIT14 | BIT13)
#define		HFA384x_RXSTATUS_MACPORT		(BIT10 | BIT9 | BIT8)
#define		HFA384x_RXSTATUS_UNDECR			(BIT1)
#define		HFA384x_RXSTATUS_FCSERR			(BIT0)
/*--------------------------------------------------------------------
Communication Frames: Test/Get/Set Field Values for Receive Frames
--------------------------------------------------------------------*/
#define		HFA384x_RXSTATUS_MSGTYPE_GET(value)	(((UINT)(value) & HFA384x_RXSTATUS_MSGTYPE) >> 13)
#define		HFA384x_RXSTATUS_MSGTYPE_SET(value)	((UINT)(value) << 13)
#define		HFA384x_RXSTATUS_MACPORT_GET(value)	(((UINT)(value) & HFA384x_RXSTATUS_MACPORT) >> 8)
#define		HFA384x_RXSTATUS_MACPORT_SET(value)	((UINT)(value) << 8)
#define		HFA384x_RXSTATUS_ISUNDECR(value)	((UINT)(value) & HFA384x_RXSTATUS_UNDECR)
#define		HFA384x_RXSTATUS_ISFCSERR(value)	((UINT)(value) & HFA384x_RXSTATUS_FCSERR)
/*--------------------------------------------------------------------
 FRAME STRUCTURES: Information Types and Information Frame Structures
----------------------------------------------------------------------
Information Types
--------------------------------------------------------------------*/
#define		HFA384x_IT_HANDOVERADDR			(0xF000)
#define		HFA384x_IT_COMMTALLIES			(0xF100)
#define		HFA384x_IT_SCANRESULTS			(0xF101)
#define		HFA384x_IT_LINKSTATUS			(0xF200)
#define		HFA384x_IT_ASSOCSTATUS			(0xF201)

/*--------------------------------------------------------------------
Information Frames Structures
----------------------------------------------------------------------
Information Frames: Notification Frame Structures
--------------------------------------------------------------------*/
/*--  Generic type, all Inf frames have this header --*/
typedef struct hfa384x_InfFrame
{
	UINT16	framelen		__WLAN_ATTRIB_PACK__;
	UINT16	infotype		__WLAN_ATTRIB_PACK__;
} hfa384x_InfFrame_t;

/*--  Notification Frame,MAC Mgmt: Handover Address --*/
typedef struct hfa384x_HandoverAddr
{
	UINT16	framelen		__WLAN_ATTRIB_PACK__;
	UINT16	infotype		__WLAN_ATTRIB_PACK__;
	UINT8	HandoverAddr[6]		__WLAN_ATTRIB_PACK__;
} hfa384x_HandoverAddr_t;

/*--  Inquiry Frame, Diagnose: Communication Tallies --*/
typedef struct hfa384x_CommTallies
{
	UINT16	framelen		__WLAN_ATTRIB_PACK__;
	UINT16	infotype		__WLAN_ATTRIB_PACK__;
	UINT16	TxUnicastFrames		__WLAN_ATTRIB_PACK__;
	UINT16	TxMulticastFrames	__WLAN_ATTRIB_PACK__;
	UINT16	TxFragments		__WLAN_ATTRIB_PACK__;
	UINT16	TxUnicastOctets		__WLAN_ATTRIB_PACK__;
	UINT16	TxMulticastOctets	__WLAN_ATTRIB_PACK__;
	UINT16	TxDeferredTrans		__WLAN_ATTRIB_PACK__;
	UINT16	TxSingleRetryFrames	__WLAN_ATTRIB_PACK__;
	UINT16	TxMultipleRetryFrames	__WLAN_ATTRIB_PACK__;
	UINT16	TxRetryLimitExceeded	__WLAN_ATTRIB_PACK__;
	UINT16	TxDiscards		__WLAN_ATTRIB_PACK__;
	UINT16	RxUnicastFrames		__WLAN_ATTRIB_PACK__;
	UINT16	RxMulticastFrames	__WLAN_ATTRIB_PACK__;
	UINT16	RxFragments		__WLAN_ATTRIB_PACK__;
	UINT16	RxUnicastOctets		__WLAN_ATTRIB_PACK__;
	UINT16	RxMulticastOctets	__WLAN_ATTRIB_PACK__;
	UINT16	RxFCSErrors		__WLAN_ATTRIB_PACK__;
	UINT16	RxDiscardsNoBuffer	__WLAN_ATTRIB_PACK__;
	UINT16	TxDiscardsWrongSA	__WLAN_ATTRIB_PACK__;
	UINT16	RxDiscardsWEPUndecr	__WLAN_ATTRIB_PACK__;
	UINT16	RxMsgInMsgFrag		__WLAN_ATTRIB_PACK__;
	UINT16	RxMsgInBadMsgFrag	__WLAN_ATTRIB_PACK__;
} hfa384x_CommTallies_t;

/*--  Inquiry Frame, Diagnose: Scan Results Subfields--*/
typedef struct hfa384x_ScanResultSub
{
	UINT16	SRT_chid		__WLAN_ATTRIB_PACK__;
	UINT16	SRT_anl			__WLAN_ATTRIB_PACK__;
	UINT16	SRT_sl			__WLAN_ATTRIB_PACK__;
	UINT8	SRT_bssid[6]		__WLAN_ATTRIB_PACK__;
	UINT16	SRT_BcnInt		__WLAN_ATTRIB_PACK__;
	UINT16	SRT_cap			__WLAN_ATTRIB_PACK__;
	UINT8	SRT_ssid[34]		__WLAN_ATTRIB_PACK__;
} hfa384x_ScanResultSub_t;

/*--  Field Masks for Scan Results Subfield SRT_cap --*/
#define		HFA384x_SRTCAP_PRIVACY			(BIT4)
#define		HFA384x_SRTCAP_CFPOLLRQ			(BIT3)
#define		HFA384x_SRTCAP_CFPOLLABLE		(BIT2)
#define		HFA384x_SRTCAP_IBSS			(BIT1)
#define		HFA384x_SRTCAP_ESS			(BIT0)
/*--  Test Field Values for Scan Results Subfield SRT_cap --*/
#define		HFA384x_SRTCAP_ISPRIVACY(value)		((UINT)(value) & HFA384x_SRTCAP_PRIVACY)
#define		HFA384x_SRTCAP_ISCFPOLLRQ(value)	((UINT)(value) & HFA384x_SRTCAP_CFPOLLRQ)
#define		HFA384x_SRTCAP_ISCFPOLLABLE(value)	((UINT)(value) & HFA384x_SRTCAP_CFPOLLABLE)
#define		HFA384x_SRTCAP_ISIBSS(value)		((UINT)(value) & HFA384x_SRTCAP_IBSS)
#define		HFA384x_SRTCAP_ISESS(value)		((UINT)(value) & HFA384x_SRTCAP_ESS)

/*--  Inquiry Frame, Diagnose: Scan Results --*/
typedef	struct ScanResultsSub
{
	UINT16	channel				__WLAN_ATTRIB_PACK__;
	UINT16	noise				__WLAN_ATTRIB_PACK__;
	UINT16	signal				__WLAN_ATTRIB_PACK__;
	UINT8	macaddr[6]			__WLAN_ATTRIB_PACK__;
	UINT16	bcnint				__WLAN_ATTRIB_PACK__;
	UINT16	capinfo				__WLAN_ATTRIB_PACK__;
	UINT8	ssid[34]			__WLAN_ATTRIB_PACK__;
} ScanResultsSub_t;

typedef struct hfa384x_ScanResults
{
	UINT16	framelen			__WLAN_ATTRIB_PACK__;
	UINT16	infotype			__WLAN_ATTRIB_PACK__;
	ScanResultsSub_t	SRT_ssid[32]	__WLAN_ATTRIB_PACK__;
} hfa384x_ScanResults_t;

/*--  Unsolicited Frame, MAC Mgmt: LinkStatus --*/
typedef struct hfa384x_LinkStatus
{
	UINT16	framelen		__WLAN_ATTRIB_PACK__;
	UINT16	infotype		__WLAN_ATTRIB_PACK__;
	UINT16	LinkStatus		__WLAN_ATTRIB_PACK__;
} hfa384x_LinkStatus_t;

#define HFA384x_LINK_NOTCONNECTED	0
#define HFA384x_LINK_CONNECTED		1
#define HFA384x_LINK_DISCONNECTED	2
#define HFA384x_LINK_AP_CHANGE		3
#define HFA384x_LINK_AP_OUTOFRANGE	4
#define HFA384x_LINK_AP_INRANGE		5
#define HFA384x_LINK_ASSOCFAIL		6

/*--  Unsolicited Frame, MAC Mgmt: AssociationStatus --*/
typedef struct hfa384x_AssocStatus
{
	UINT16	framelen		__WLAN_ATTRIB_PACK__;
	UINT16	infotype		__WLAN_ATTRIB_PACK__;
	UINT16	AssocStatus		__WLAN_ATTRIB_PACK__;
	UINT8	StaAddr[6]		__WLAN_ATTRIB_PACK__;
	UINT8	OldAPAddr[6]		__WLAN_ATTRIB_PACK__; /* optional */
} hfa384x_AssocStatus_t;

#define HFA384x_ASSOCSTATUS_ASSOC	0
#define HFA384x_ASSOCSTATIS_REASSOC	1
#define HFA384x_ASSOCSTATUS_DISASSOC	2
#define HFA384x_ASSOCSTATUS_ASSOCFAIL	3
#define HFA384x_ASSOCSTATUS_AUTHFAIL	4


/*--  MAC state structure, argument to all functions --*/
typedef struct hfa384x
{
	/* Resource config */
	UINT32		iobase;		/* base address */
	UINT32		irq;		/* irq number */

	/* Controller state */
	UINT32		state;
	UINT32		isap;
	UINT8		port_enabled[HFA384x_NUMPORTS_MAX];
	UINT32		bap;		/* BAP context.  Defines which bap */
					/*  should be used by functions that */
					/*  may be called in int or non-int */
					/*  context, should be set and cleared */
					/*  in int handler */

	/* Command support */
	spinlock_t	cmdlock;
	UINT16		lastcmd;
	UINT16		status;		/* in host order */
	UINT16		resp0;		/* in host order */
	UINT16		resp1;		/* in host order */
	UINT16		resp2;		/* in host order */

	/* BAP support */
	spinlock_t	baplock[2];	
} hfa384x_t;


/*=============================================================*/
/*--- Function Declarations -----------------------------------*/
/*=============================================================*/
void hfa384x_inithw( hfa384x_t *hw, UINT irq, UINT iobase);

int hfa384x_cmd_initialize(hfa384x_t *hw);
int hfa384x_cmd_enable(hfa384x_t *hw, UINT8 macport);
int hfa384x_cmd_disable(hfa384x_t *hw, UINT8 macport);
int hfa384x_cmd_diagnose(hfa384x_t *hw);
int hfa384x_cmd_allocate(hfa384x_t *hw, UINT16 len);
int hfa384x_cmd_transmit(hfa384x_t *hw, UINT16 reclaim, UINT16 fid);
int hfa384x_cmd_notify(hfa384x_t *hw, UINT16 reclaim, UINT16 fid);
int hfa384x_cmd_inquiry(hfa384x_t *hw, UINT16 fid);
int hfa384x_cmd_access(hfa384x_t *hw, UINT16 write, UINT16 rid);
int hfa384x_cmd_download(hfa384x_t *hw, UINT16 mode, UINT16 lowaddr, 
				UINT16 highaddr, UINT16 codelen);

int hfa384x_copy_from_bap(hfa384x_t *hw, UINT16 bap, UINT16 id, UINT16 offset,
				void *buf, UINT len);

int hfa384x_copy_to_bap(hfa384x_t *hw, UINT16 bap, UINT16 id, UINT16 offset,
				void *buf, UINT len);

int hfa384x_getconfig(hfa384x_t *hw, UINT16 rid, void *buf, UINT16 len);
int hfa384x_getconfig16(hfa384x_t *hw, UINT16 rid, void *val);
int hfa384x_setconfig(hfa384x_t *hw, UINT16 rid, void *buf, UINT16 len);
int hfa384x_setconfig16(hfa384x_t *hw, UINT16 rid, UINT16 val);

int hfa384x_docmd_wait( hfa384x_t *hw, UINT16 cmd, UINT16 parm0, UINT16 parm1, UINT16 parm2);

/*=============================================================*/
/*--- Inline Function Definitions (if supported) --------------*/
/*=============================================================*/


#endif  /* _HFA384x_H */

