/* prism2mgmt.c: Management request handler functions.
* --------------------------------------------------------------------
*
* Linux WLAN 
*
* The contents of this file are subject to the Mozilla Public
* License Version 1.0 (the "License"); you may not use this file
* except in compliance with the License. You may obtain a copy of
* the License at http://www.mozilla.org/MPL/
*
* Software distributed under the License is distributed on an "AS
* IS" basis, WITHOUT WARRANTY OF ANY KIND, either express or
* implied. See the License for the specific language governing
* rights and limitations under the License.
*
* The initial developer of the original code is Mark S. Mathews
* <mark@absoval.com>.  Portions created by Mark S. Mathews
* are Copyright (C) 1998 AbsoluteValue Software, Inc.  All Rights Reserved.
*   
* --------------------------------------------------------------------
*
* The initial author may be reached as mark@absoval.com, or 
* C/O AbsoluteValue Software Inc., P.O. Box 941149, 
* Maitland, FL, 32794-1149
*
* --------------------------------------------------------------------
*
* The functions in this file handle management requests sent from
* user mode.
*
* --------------------------------------------------------------------
*/

/*================================================================*/
/* System Includes */

#define __NO_VERSION__

#include <linux/config.h>
#define WLAN_DBVAR	prism2_debug
#include <wlan/wlan_compat.h>

#include <linux/version.h>
#include <linux/module.h>
#include <linux/kernel.h>
#include <linux/sched.h>
#include <linux/types.h>
#include <linux/malloc.h>
#include <linux/netdevice.h>
#include <asm/io.h>
#include <asm/delay.h>

#include <pcmcia/config.h>
#include <pcmcia/k_compat.h>
#include <pcmcia/version.h>
#include <pcmcia/cs_types.h>
#include <pcmcia/cs.h>
#include <pcmcia/cistpl.h>
#include <pcmcia/ds.h>
#include <pcmcia/cisreg.h>
#include <pcmcia/driver_ops.h>

/*================================================================*/
/* Project Includes */

#include <wlan/version.h>
#include <wlan/p80211types.h>
#include <wlan/p80211hdr.h>
#include <wlan/p80211mgmt.h>
#include <wlan/p80211conv.h>
#include <wlan/p80211msg.h>
#include <wlan/p80211netdev.h>
#include <wlan/p80211metadef.h>
#include <wlan/p80211metastruct.h>
#include <prism2/hfa384x.h>
#include <prism2/prism2mgmt.h>

/*================================================================*/
/* Local Constants */


/*================================================================*/
/* Local Macros */


/*================================================================*/
/* Local Types */


/*================================================================*/
/* Local Static Definitions */


/*================================================================*/
/* Local Function Declarations */


/*================================================================*/
/* Function Definitions */

/*----------------------------------------------------------------
* prism2mgmt_mibget
*
* Retrieve the value of a mib item.
*
* Arguments:
*	wlandev		wlan device structure
*	msgp		ptr to msg buffer
*
* Returns: 
*	0	success and done
*	<0	success, but we're waiting for something to finish.
*	>0	an error occurred while handling the message.
* Side effects:
*
* Call context:
*	process thread  (usually)
*	interrupt
----------------------------------------------------------------*/
int prism2mgmt_mibget(wlandevice_t *wlandev, void *msgp)
{
	prism2sta_priv_t	*priv = (prism2sta_priv_t*)wlandev->priv;
	hfa384x_t		*hw = priv->hw;
	int 			result = 0;
	p80211msg_req_mibset_t	*msg = msgp;
	DBFENTER;

	/* TODO: remove the following line, it's just to get rid of warnings for now */
	msg->resultcode.data = hw->bap; 
	msg->resultcode.data = P80211ENUM_resultcode_not_supported;

	DBFEXIT;
	return result;
}


/*----------------------------------------------------------------
* prism2mgmt_mibset
*
* Set the value of a mib item.
*
* Arguments:
*	wlandev		wlan device structure
*	msgp		ptr to msg buffer
*
* Returns: 
*	0	success and done
*	<0	success, but we're waiting for something to finish.
*	>0	an error occurred while handling the message.
* Side effects:
*
* Call context:
*	process thread  (usually)
*	interrupt
----------------------------------------------------------------*/
int prism2mgmt_mibset(wlandevice_t *wlandev, void *msgp)
{
	prism2sta_priv_t	*priv = (prism2sta_priv_t*)wlandev->priv;
	hfa384x_t		*hw = priv->hw;
	int 			result = 0;
	p80211msg_req_mibget_t	*msg = msgp;
	p80211itemd_t		*mibitem = (p80211itemd_t*)msg->mibattribute.data;
	DBFENTER;

	/* Ok, here's the list */
	switch( mibitem->did ) 
	{
	case DIDmib_dot11smt_dot11StationConfigTable_dot11DesiredSSID:
		{
			hfa384x_cnfDesiredSSID_t	ssid;
			memset(&ssid, 0, sizeof(ssid));
			ssid.reclen = 18;
			ssid.rid = HFA384x_RID_CNFDESIREDSSID;
			*((UINT16*)ssid.cnfDesiredSSID) = mibitem->data[0]; /* len */
			memcpy(ssid.cnfDesiredSSID+2, 
				mibitem->data + 1, mibitem->data[0]);
			hfa384x_setconfig( hw, 
				HFA384x_RID_CNFDESIREDSSID, &ssid, sizeof(ssid));

			msg->resultcode.did = DIDmsg_dot11req_mibset_resultcode;
			msg->resultcode.len = 4;
			msg->resultcode.data = P80211ENUM_resultcode_success;
		}
		break;
	default:
		msg->resultcode.data = P80211ENUM_resultcode_not_supported;

	}

	DBFEXIT;
	return result;
}


/*----------------------------------------------------------------
* prism2mgmt_powermgmt
*
* Set the power management state of this station's MAC.
*
* Arguments:
*	wlandev		wlan device structure
*	msgp		ptr to msg buffer
*
* Returns: 
*	0	success and done
*	<0	success, but we're waiting for something to finish.
*	>0	an error occurred while handling the message.
* Side effects:
*
* Call context:
*	process thread  (usually)
*	interrupt
----------------------------------------------------------------*/
int prism2mgmt_powermgmt(wlandevice_t *wlandev, void *msgp)
{
	prism2sta_priv_t	*priv = (prism2sta_priv_t*)wlandev->priv;
	hfa384x_t		*hw = priv->hw;
	int 			result = 0;
	p80211msg_req_powermgmt_t	*msg = msgp;
	DBFENTER;

	/* TODO: remove the following line, it's just to get rid of warnings for now */
	msg->resultcode.data = hw->bap; 
	msg->resultcode.data = P80211ENUM_resultcode_not_supported;

	DBFEXIT;
	return result;
}


/*----------------------------------------------------------------
* prism2mgmt_scan
*
* Initiate a scan for BSSs.
*
* Arguments:
*	wlandev		wlan device structure
*	msgp		ptr to msg buffer
*
* Returns: 
*	0	success and done
*	<0	success, but we're waiting for something to finish.
*	>0	an error occurred while handling the message.
* Side effects:
*
* Call context:
*	process thread  (usually)
*	interrupt
----------------------------------------------------------------*/
int prism2mgmt_scan(wlandevice_t *wlandev, void *msgp)
{
	prism2sta_priv_t	*priv = (prism2sta_priv_t*)wlandev->priv;
	hfa384x_t		*hw = priv->hw;
	int 			result = 0;
	p80211msg_req_scan_t	*msg = msgp;
	DBFENTER;

	/* TODO: remove the following line, it's just to get rid of warnings for now */
	msg->resultcode.data = hw->bap; 
	msg->resultcode.data = P80211ENUM_resultcode_not_supported;

	DBFEXIT;
	return result;
}


/*----------------------------------------------------------------
* prism2mgmt_scan_results
*
* Retrieve the BSS description for one of the BSSs identified in
* a scan.
*
* Arguments:
*	wlandev		wlan device structure
*	msgp		ptr to msg buffer
*
* Returns: 
*	0	success and done
*	<0	success, but we're waiting for something to finish.
*	>0	an error occurred while handling the message.
* Side effects:
*
* Call context:
*	process thread  (usually)
*	interrupt
----------------------------------------------------------------*/
int prism2mgmt_scan_results(wlandevice_t *wlandev, void *msgp)
{
	prism2sta_priv_t	*priv = (prism2sta_priv_t*)wlandev->priv;
	hfa384x_t		*hw = priv->hw;
	int 			result = 0;
	p80211msg_req_scan_results_t	*msg = msgp;
	DBFENTER;

	/* TODO: remove the following line, it's just to get rid of warnings for now */
	msg->resultcode.data = hw->bap; 
	msg->resultcode.data = P80211ENUM_resultcode_not_supported;

	DBFEXIT;
	return result;
}


/*----------------------------------------------------------------
* prism2mgmt_join
*
* Join a BSS whose BSS description was previously obtained with
* a scan.
*
* Arguments:
*	wlandev		wlan device structure
*	msgp		ptr to msg buffer
*
* Returns: 
*	0	success and done
*	<0	success, but we're waiting for something to finish.
*	>0	an error occurred while handling the message.
* Side effects:
*
* Call context:
*	process thread  (usually)
*	interrupt
----------------------------------------------------------------*/
int prism2mgmt_join(wlandevice_t *wlandev, void *msgp)
{
	prism2sta_priv_t	*priv = (prism2sta_priv_t*)wlandev->priv;
	hfa384x_t		*hw = priv->hw;
	int 			result = 0;
	p80211msg_req_join_t	*msg = msgp;
	DBFENTER;

	/* TODO: remove the following line, it's just to get rid of warnings for now */
	msg->resultcode.data = hw->bap; 
	msg->resultcode.data = P80211ENUM_resultcode_not_supported;

	DBFEXIT;
	return result;
}


/*----------------------------------------------------------------
* prism2mgmt_authenticate
*
* Station should be begin an authentication exchange.
*
* Arguments:
*	wlandev		wlan device structure
*	msgp		ptr to msg buffer
*
* Returns: 
*	0	success and done
*	<0	success, but we're waiting for something to finish.
*	>0	an error occurred while handling the message.
* Side effects:
*
* Call context:
*	process thread  (usually)
*	interrupt
----------------------------------------------------------------*/
int prism2mgmt_authenticate(wlandevice_t *wlandev, void *msgp)
{
	prism2sta_priv_t	*priv = (prism2sta_priv_t*)wlandev->priv;
	hfa384x_t		*hw = priv->hw;
	int 			result = 0;
	p80211msg_req_authenticate_t	*msg = msgp;
	DBFENTER;

	/* TODO: remove the following line, it's just to get rid of warnings for now */
	msg->resultcode.data = hw->bap; 
	msg->resultcode.data = P80211ENUM_resultcode_not_supported;

	DBFEXIT;
	return result;
}


/*----------------------------------------------------------------
* prism2mgmt_deauthenticate
*
* Send a deauthenticate notification.
*
* Arguments:
*	wlandev		wlan device structure
*	msgp		ptr to msg buffer
*
* Returns: 
*	0	success and done
*	<0	success, but we're waiting for something to finish.
*	>0	an error occurred while handling the message.
* Side effects:
*
* Call context:
*	process thread  (usually)
*	interrupt
----------------------------------------------------------------*/
int prism2mgmt_deauthenticate(wlandevice_t *wlandev, void *msgp)
{
	prism2sta_priv_t	*priv = (prism2sta_priv_t*)wlandev->priv;
	hfa384x_t		*hw = priv->hw;
	int 			result = 0;
	p80211msg_req_deauthenticate_t	*msg = msgp;
	DBFENTER;

	/* TODO: remove the following line, it's just to get rid of warnings for now */
	msg->resultcode.data = hw->bap; 
	msg->resultcode.data = P80211ENUM_resultcode_not_supported;

	DBFEXIT;
	return result;
}


/*----------------------------------------------------------------
* prism2mgmt_associate
*
* Associate with an ESS.
*
* Arguments:
*	wlandev		wlan device structure
*	msgp		ptr to msg buffer
*
* Returns: 
*	0	success and done
*	<0	success, but we're waiting for something to finish.
*	>0	an error occurred while handling the message.
* Side effects:
*
* Call context:
*	process thread  (usually)
*	interrupt
----------------------------------------------------------------*/
int prism2mgmt_associate(wlandevice_t *wlandev, void *msgp)
{
	prism2sta_priv_t	*priv = (prism2sta_priv_t*)wlandev->priv;
	hfa384x_t		*hw = priv->hw;
	int 			result = 0;
	UINT16			reg;
	p80211msg_req_associate_t	*msg = msgp;
	DBFENTER;

	/* Set the PortType */
	hfa384x_setconfig16(hw, 0xfc00, 1); /* ESS port */

	/* Enable the interrupts */
	reg = HFA384x_INTEN_INFDROP_SET(1) |
		HFA384x_INTEN_INFO_SET(1) |
		HFA384x_INTEN_ALLOC_SET(1) |
		HFA384x_INTEN_TXEXC_SET(1) |
		HFA384x_INTEN_TX_SET(1) |
		HFA384x_INTEN_RX_SET(1);
	outw( reg, HFA384x_INTEN(hw->iobase));
		
	/* Enable the Port */
	hfa384x_cmd_enable(hw, 0);

	/* Set the resultcode */
	msg->resultcode.did =  DIDmsg_dot11req_associate_resultcode;
	msg->resultcode.len = 4;
	msg->resultcode.data = P80211ENUM_resultcode_success;


	DBFEXIT;
	return result;
}


/*----------------------------------------------------------------
* prism2mgmt_reassociate
*
* Renew association because of a BSS change.
*
* Arguments:
*	wlandev		wlan device structure
*	msgp		ptr to msg buffer
*
* Returns: 
*	0	success and done
*	<0	success, but we're waiting for something to finish.
*	>0	an error occurred while handling the message.
* Side effects:
*
* Call context:
*	process thread  (usually)
*	interrupt
----------------------------------------------------------------*/
int prism2mgmt_reassociate(wlandevice_t *wlandev, void *msgp)
{
	prism2sta_priv_t	*priv = (prism2sta_priv_t*)wlandev->priv;
	hfa384x_t		*hw = priv->hw;
	int 			result = 0;
	p80211msg_req_reassociate_t	*msg = msgp;
	DBFENTER;

	/* TODO: remove the following line, it's just to get rid of warnings for now */
	msg->resultcode.data = hw->bap; 
	msg->resultcode.data = P80211ENUM_resultcode_not_supported;

	DBFEXIT;
	return result;
}


/*----------------------------------------------------------------
* prism2mgmt_disassociate
*
* Send a disassociation notification.
*
* Arguments:
*	wlandev		wlan device structure
*	msgp		ptr to msg buffer
*
* Returns: 
*	0	success and done
*	<0	success, but we're waiting for something to finish.
*	>0	an error occurred while handling the message.
* Side effects:
*
* Call context:
*	process thread  (usually)
*	interrupt
----------------------------------------------------------------*/
int prism2mgmt_disassociate(wlandevice_t *wlandev, void *msgp)
{
	prism2sta_priv_t	*priv = (prism2sta_priv_t*)wlandev->priv;
	hfa384x_t		*hw = priv->hw;
	int 			result = 0;
	p80211msg_req_disassociate_t	*msg = msgp;
	DBFENTER;

	/* TODO: remove the following line, it's just to get rid of warnings for now */
	msg->resultcode.data = hw->bap; 
	msg->resultcode.data = P80211ENUM_resultcode_not_supported;

	DBFEXIT;
	return result;
}


/*----------------------------------------------------------------
* prism2mgmt_start
*
* Start a BSS.  Any station can do this for IBSS, only AP for ESS.
*
* Arguments:
*	wlandev		wlan device structure
*	msgp		ptr to msg buffer
*
* Returns: 
*	0	success and done
*	<0	success, but we're waiting for something to finish.
*	>0	an error occurred while handling the message.
* Side effects:
*
* Call context:
*	process thread  (usually)
*	interrupt
----------------------------------------------------------------*/
int prism2mgmt_start(wlandevice_t *wlandev, void *msgp)
{
	prism2sta_priv_t	*priv = (prism2sta_priv_t*)wlandev->priv;
	hfa384x_t		*hw = priv->hw;
	int 			result = 0;
	p80211msg_req_start_t	*msg = msgp;
	DBFENTER;

	/* TODO: remove the following line, it's just to get rid of warnings for now */
	msg->resultcode.data = hw->bap; 
	msg->resultcode.data = P80211ENUM_resultcode_not_supported;

	DBFEXIT;
	return result;
}


	
