/* p80211metamsg.c: Defines the data and functions for 802.11 message
*  metadata
*   --------------------------------------------------------------------
*
* Linux WLAN 
*
* The contents of this file are subject to the Mozilla Public
* License Version 1.0 (the "License"); you may not use this file
* except in compliance with the License. You may obtain a copy of
* the License at http://www.mozilla.org/MPL/
*
* Software distributed under the License is distributed on an "AS
* IS" basis, WITHOUT WARRANTY OF ANY KIND, either express or
* implied. See the License for the specific language governing
* rights and limitations under the License.
*
* The initial developer of the original code is Mark S. Mathews
* <mark@absoval.com>.  Portions created by Mark S. Mathews
* are Copyright (C) 1998 AbsoluteValue Software, Inc.  All Rights Reserved.
*   
* --------------------------------------------------------------------
*
* The initial author may be reached as mark@absoval.com, or 
* C/O AbsoluteValue Software Inc., P.O. Box 941149, 
* Maitland, FL, 32794-1149
*
* --------------------------------------------------------------------
*
* This file defines the metadata for message contents and argument
* metadata.
*
*   --------------------------------------------------------------------
*/


/*================================================================*/
/* System Includes */

#include <stdio.h>
#include <stdlib.h>


/*================================================================*/
/* Project Includes */

#include <wlan/wlan_compat.h>
#include <wlan/p80211types.h>
#include <wlan/p80211meta.h>
#include <wlan/p80211msg.h>
#include <wlan/p80211metamsg.h>

/*================================================================*/
/* Local Constants */


/*================================================================*/
/* Local Macros */


/*================================================================*/
/* Local Types */


/*================================================================*/
/* Local Static Definitions */

/*====================================================================*/
/* Message Argument Metadata                                          */
/*====================================================================*/

/*--------------------------------------------------------------------*/
/* metadata for the mibget request message arguments */

extern	UINT32	MKREQMETASIZE(mibget);

p80211meta_t MKREQMETANAME(mibget)[] = {
{
	/* name        */ (char *)&(MKREQMETASIZE(mibget)),
	/* did         */ 0,
	/* flags       */ 0,
	/* min         */ 0,
	/* max         */ 0,
	/* maxlen      */ 0,
	/* enumptr     */ NULL,
	/* collptr     */ NULL,
	/* totextptr   */ NULL,
	/* fromtextptr */ NULL,
	/* validfunptr */ NULL
},
{
	/* name        */ MKITEMNAME("mibattribute"),
	/* did         */ P80211DID_MKID(0,0,0,0,0,0,P80211_TYPE_UNKDATA),
	/* flags       */ P80211ITEM_SETFLAGS(ISREQUIRED, ISREQUEST, 0UL),
	/* min         */ 0,
	/* max         */ 0,
	/* maxlen      */ MAXLEN_MIBATTRIBUTE,
	/* enumptr     */ NULL,
	/* collptr     */ NULL,
	/* totextptr   */ p80211_totext_getmibattribute,
	/* fromtextptr */ p80211_fromtext_getmibattribute,
	/* validfunptr */ p80211_isvalid_getmibattribute
},
{
	/* name        */ MKITEMNAME("resultcode"),
	/* did         */ P80211DID_MKID(0,0,0,0,0,0,P80211_TYPE_ENUMINT),
	/* flags       */ P80211ITEM_SETFLAGS(ISREQUIRED, 0UL, ISCONFIRM),
	/* min         */ 0,
	/* max         */ 0,
	/* maxlen      */ 0,
	/* enumptr     */ &MKENUMNAME(resultcode),
	/* collptr     */ NULL,
	/* totextptr   */ p80211_totext_enumint,
	/* fromtextptr */ p80211_fromtext_enumint,
	/* validfunptr */ p80211_isvalid_enumint
}
};  /* end of mibget request message metadata list */

UINT32	MKREQMETASIZE(mibget) = sizeof(MKREQMETANAME(mibget))/sizeof(p80211meta_t);

/*--------------------------------------------------------------------*/
/* metadata for the mibset request message arguments */

extern	UINT32	MKREQMETASIZE(mibset);

p80211meta_t MKREQMETANAME(mibset)[] = {
{
	/* name        */ (char *)&(MKREQMETASIZE(mibset)),
	/* did         */ 0,
	/* flags       */ 0,
	/* min         */ 0,
	/* max         */ 0,
	/* maxlen      */ 0,
	/* enumptr     */ NULL,
	/* collptr     */ NULL,
	/* totextptr   */ NULL,
	/* fromtextptr */ NULL,
	/* validfunptr */ NULL
},
{
	/* name        */ MKITEMNAME("mibattribute"),
	/* did         */ P80211DID_MKID(0,0,0,0,0,0,P80211_TYPE_UNKDATA),
	/* flags       */ P80211ITEM_SETFLAGS(ISREQUIRED, ISREQUEST, 0UL),
	/* min         */ 0,
	/* max         */ 0,
	/* maxlen      */ MAXLEN_MIBATTRIBUTE,
	/* enumptr     */ NULL,
	/* collptr     */ NULL,
	/* totextptr   */ p80211_totext_setmibattribute,
	/* fromtextptr */ p80211_fromtext_setmibattribute,
	/* validfunptr */ p80211_isvalid_setmibattribute
},
{
	/* name        */ MKITEMNAME("resultcode"),
	/* did         */ P80211DID_MKID(0,0,0,0,0,0,P80211_TYPE_ENUMINT),
	/* flags       */ P80211ITEM_SETFLAGS(ISREQUIRED, 0UL, ISCONFIRM),
	/* min         */ 0,
	/* max         */ 0,
	/* maxlen      */ 0,
	/* enumptr     */ &MKENUMNAME(resultcode),
	/* collptr     */ NULL,
	/* totextptr   */ p80211_totext_enumint,
	/* fromtextptr */ p80211_fromtext_enumint,
	/* validfunptr */ p80211_isvalid_enumint
}
};  /* end of mibset request message metadata list */

UINT32	MKREQMETASIZE(mibset) = 
		sizeof(MKREQMETANAME(mibset))/sizeof(p80211meta_t);

/*--------------------------------------------------------------------*/
/* metadata for the powermgmt request message arguments */

extern	UINT32	MKREQMETASIZE(powermgmt);

p80211meta_t MKREQMETANAME(powermgmt)[] = {
{
	/* name        */ (char *)&(MKREQMETASIZE(powermgmt)),
	/* did         */ 0,
	/* flags       */ 0,
	/* min         */ 0,
	/* max         */ 0,
	/* maxlen      */ 0,
	/* enumptr     */ NULL,
	/* collptr     */ NULL,
	/* totextptr   */ NULL,
	/* fromtextptr */ NULL,
	/* validfunptr */ NULL
},
{
	/* name        */ MKITEMNAME("powermgmtmode"),
	/* did         */ P80211DID_MKID(0,0,0,0,0,0,P80211_TYPE_ENUMINT),
	/* flags       */ P80211ITEM_SETFLAGS(ISREQUIRED, ISREQUEST, 0UL),
	/* min         */ 0,
	/* max         */ 0,
	/* maxlen      */ 0,
	/* enumptr     */ &MKENUMNAME(powermgmt),
	/* collptr     */ NULL,
	/* totextptr   */ p80211_totext_enumint,
	/* fromtextptr */ p80211_fromtext_enumint,
	/* validfunptr */ p80211_isvalid_enumint
},
{
	/* name        */ MKITEMNAME("wakeup"),
	/* did         */ P80211DID_MKID(0,0,0,0,0,0,P80211_TYPE_ENUMINT),
	/* flags       */ P80211ITEM_SETFLAGS(ISREQUIRED, ISREQUEST, 0UL),
	/* min         */ 0,
	/* max         */ 0,
	/* maxlen      */ 0,
	/* enumptr     */ &MKENUMNAME(truth),
	/* collptr     */ NULL,
	/* totextptr   */ p80211_totext_enumint,
	/* fromtextptr */ p80211_fromtext_enumint,
	/* validfunptr */ p80211_isvalid_enumint
},
{
	/* name        */ MKITEMNAME("receivedtims"),
	/* did         */ P80211DID_MKID(0,0,0,0,0,0,P80211_TYPE_ENUMINT),
	/* flags       */ P80211ITEM_SETFLAGS(ISREQUIRED, ISREQUEST, 0UL),
	/* min         */ 0,
	/* max         */ 0,
	/* maxlen      */ 0,
	/* enumptr     */ &MKENUMNAME(truth),
	/* collptr     */ NULL,
	/* totextptr   */ p80211_totext_enumint,
	/* fromtextptr */ p80211_fromtext_enumint,
	/* validfunptr */ p80211_isvalid_enumint
},
{
	/* name        */ MKITEMNAME("resultcode"),
	/* did         */ P80211DID_MKID(0,0,0,0,0,0,P80211_TYPE_ENUMINT),
	/* flags       */ P80211ITEM_SETFLAGS(ISREQUIRED, 0UL, ISCONFIRM),
	/* min         */ 0,
	/* max         */ 0,
	/* maxlen      */ 0,
	/* enumptr     */ &MKENUMNAME(resultcode),
	/* collptr     */ NULL,
	/* totextptr   */ p80211_totext_enumint,
	/* fromtextptr */ p80211_fromtext_enumint,
	/* validfunptr */ p80211_isvalid_enumint
}
};  /* end of powermgmt request message metadata list */

UINT32	MKREQMETASIZE(powermgmt) = 
		sizeof(MKREQMETANAME(powermgmt))/sizeof(p80211meta_t);

/*--------------------------------------------------------------------*/
/* metadata for the scan request message arguments */

extern	UINT32	MKREQMETASIZE(scan);

p80211meta_t MKREQMETANAME(scan)[] = {
{
	/* name        */ (char *)&(MKREQMETASIZE(scan)),
	/* did         */ 0,
	/* flags       */ 0,
	/* min         */ 0,
	/* max         */ 0,
	/* maxlen      */ 0,
	/* enumptr     */ NULL,
	/* collptr     */ NULL,
	/* totextptr   */ NULL,
	/* fromtextptr */ NULL,
	/* validfunptr */ NULL
},
{
	/* name        */ MKITEMNAME("bsstype"),
	/* did         */ P80211DID_MKID(0,0,0,0,0,0,P80211_TYPE_ENUMINT),
	/* flags       */ P80211ITEM_SETFLAGS(ISREQUIRED, ISREQUEST, 0UL),
	/* min         */ 0,
	/* max         */ 0,
	/* maxlen      */ 0,
	/* enumptr     */ &MKENUMNAME(bsstype),
	/* collptr     */ NULL,
	/* totextptr   */ p80211_totext_enumint,
	/* fromtextptr */ p80211_fromtext_enumint,
	/* validfunptr */ p80211_isvalid_enumint
},
{
	/* name        */ MKITEMNAME("bssid"),
	/* did         */ P80211DID_MKID(0,0,0,0,0,0,P80211_TYPE_OCTETSTR),
	/* flags       */ P80211ITEM_SETFLAGS(ISREQUIRED, ISREQUEST, 0UL),
	/* min         */ 0,
	/* max         */ 0,
	/* maxlen      */ MAXLEN_PSTR6,
	/* enumptr     */ NULL,
	/* collptr     */ NULL,
	/* totextptr   */ p80211_totext_octetstr,
	/* fromtextptr */ p80211_fromtext_octetstr,
	/* validfunptr */ p80211_isvalid_octetstr
},
{
	/* name        */ MKITEMNAME("ssid"),
	/* did         */ P80211DID_MKID(0,0,0,0,0,0,P80211_TYPE_OCTETSTR),
	/* flags       */ P80211ITEM_SETFLAGS(ISREQUIRED, ISREQUEST, 0UL),
	/* min         */ 0,
	/* max         */ 0,
	/* maxlen      */ MAXLEN_PSTR32,
	/* enumptr     */ NULL,
	/* collptr     */ NULL,
	/* totextptr   */ p80211_totext_octetstr,
	/* fromtextptr */ p80211_fromtext_octetstr,
	/* validfunptr */ p80211_isvalid_octetstr
},
{
	/* name        */ MKITEMNAME("scantype"),
	/* did         */ P80211DID_MKID(0,0,0,0,0,0,P80211_TYPE_ENUMINT),
	/* flags       */ P80211ITEM_SETFLAGS(ISREQUIRED, ISREQUEST, 0UL),
	/* min         */ 0,
	/* max         */ 0,
	/* maxlen      */ 0,
	/* enumptr     */ &MKENUMNAME(scantype),
	/* collptr     */ NULL,
	/* totextptr   */ p80211_totext_enumint,
	/* fromtextptr */ p80211_fromtext_enumint,
	/* validfunptr */ p80211_isvalid_enumint
},
{
	/* name        */ MKITEMNAME("probedelay"),
	/* did         */ P80211DID_MKID(0,0,0,0,0,0,P80211_TYPE_INT),
	/* flags       */ P80211ITEM_SETFLAGS(ISREQUIRED, ISREQUEST, 0UL),
	/* min         */ 0,
	/* max         */ 0,
	/* maxlen      */ 0,
	/* enumptr     */ NULL,
	/* collptr     */ NULL,
	/* totextptr   */ p80211_totext_int,
	/* fromtextptr */ p80211_fromtext_int,
	/* validfunptr */ p80211_isvalid_int
},
{
	/* name        */ MKITEMNAME("channellist"),
	/* did         */ P80211DID_MKID(0,0,0,0,0,0,P80211_TYPE_OCTETSTR),
	/* flags       */ P80211ITEM_SETFLAGS(ISREQUIRED, ISREQUEST, 0UL),
	/* min         */ 0,
	/* max         */ 0,
	/* maxlen      */ MAXLEN_PSTR14,
	/* enumptr     */ NULL,
	/* collptr     */ NULL,
	/* totextptr   */ p80211_totext_octetstr,
	/* fromtextptr */ p80211_fromtext_octetstr,
	/* validfunptr */ p80211_isvalid_octetstr
},
{
	/* name        */ MKITEMNAME("minchanneltime"),
	/* did         */ P80211DID_MKID(0,0,0,0,0,0,P80211_TYPE_INT),
	/* flags       */ P80211ITEM_SETFLAGS(ISREQUIRED, ISREQUEST, 0UL),
	/* min         */ 0,
	/* max         */ 0,
	/* maxlen      */ 0,
	/* enumptr     */ NULL,
	/* collptr     */ NULL,
	/* totextptr   */ p80211_totext_int,
	/* fromtextptr */ p80211_fromtext_int,
	/* validfunptr */ p80211_isvalid_int
},
{
	/* name        */ MKITEMNAME("maxchanneltime"),
	/* did         */ P80211DID_MKID(0,0,0,0,0,0,P80211_TYPE_INT),
	/* flags       */ P80211ITEM_SETFLAGS(ISREQUIRED, ISREQUEST, 0UL),
	/* min         */ 0,
	/* max         */ 0,
	/* maxlen      */ 0,
	/* enumptr     */ NULL,
	/* collptr     */ NULL,
	/* totextptr   */ p80211_totext_int,
	/* fromtextptr */ p80211_fromtext_int,
	/* validfunptr */ p80211_isvalid_int
},
{
	/* name        */ MKITEMNAME("resultcode"),
	/* did         */ P80211DID_MKID(0,0,0,0,0,0,P80211_TYPE_ENUMINT),
	/* flags       */ P80211ITEM_SETFLAGS(ISREQUIRED, 0UL, ISCONFIRM),
	/* min         */ 0,
	/* max         */ 0,
	/* maxlen      */ 0,
	/* enumptr     */ &MKENUMNAME(resultcode),
	/* collptr     */ NULL,
	/* totextptr   */ p80211_totext_enumint,
	/* fromtextptr */ p80211_fromtext_enumint,
	/* validfunptr */ p80211_isvalid_enumint
},
{
	/* name        */ MKITEMNAME("numbss"),
	/* did         */ P80211DID_MKID(0,0,0,0,0,0,P80211_TYPE_INT),
	/* flags       */ P80211ITEM_SETFLAGS(ISREQUIRED, 0UL, ISCONFIRM),
	/* min         */ 0,
	/* max         */ 0,
	/* maxlen      */ 0,
	/* enumptr     */ NULL,
	/* collptr     */ NULL,
	/* totextptr   */ p80211_totext_int,
	/* fromtextptr */ p80211_fromtext_int,
	/* validfunptr */ p80211_isvalid_int
}
};  /* end of scan request message metadata list */

UINT32	MKREQMETASIZE(scan) = 
		sizeof(MKREQMETANAME(scan))/sizeof(p80211meta_t);

/*--------------------------------------------------------------------*/
/* metadata for the scan_results request message arguments */

extern	UINT32	MKREQMETASIZE(scan_results);

p80211meta_t MKREQMETANAME(scan_results)[] = {
{
	/* name        */ (char *)&(MKREQMETASIZE(scan_results)),
	/* did         */ 0,
	/* flags       */ 0,
	/* min         */ 0,
	/* max         */ 0,
	/* maxlen      */ 0,
	/* enumptr     */ NULL,
	/* collptr     */ NULL,
	/* totextptr   */ NULL,
	/* fromtextptr */ NULL,
	/* validfunptr */ NULL
},
{
	/* name        */ MKITEMNAME("bssindex"),
	/* did         */ P80211DID_MKID(0,0,0,0,0,0,P80211_TYPE_INT),
	/* flags       */ P80211ITEM_SETFLAGS(ISREQUIRED, ISREQUEST, 0UL),
	/* min         */ 0,
	/* max         */ 0,
	/* maxlen      */ 0,
	/* enumptr     */ NULL,
	/* collptr     */ NULL,
	/* totextptr   */ p80211_totext_int,
	/* fromtextptr */ p80211_fromtext_int,
	/* validfunptr */ p80211_isvalid_int
},
{
	/* name        */ MKITEMNAME("resultcode"),
	/* did         */ P80211DID_MKID(0,0,0,0,0,0,P80211_TYPE_ENUMINT),
	/* flags       */ P80211ITEM_SETFLAGS(ISREQUIRED, 0UL, ISCONFIRM),
	/* min         */ 0,
	/* max         */ 0,
	/* maxlen      */ 0,
	/* enumptr     */ &MKENUMNAME(resultcode),
	/* collptr     */ NULL,
	/* totextptr   */ p80211_totext_enumint,
	/* fromtextptr */ p80211_fromtext_enumint,
	/* validfunptr */ p80211_isvalid_enumint
},
{
	/* name        */ "bssid",
	/* did         */ P80211DID_MKID(0,0,0,0,0,0,P80211_TYPE_OCTETSTR),
	/* flags       */ P80211ITEM_SETFLAGS(ISREQUIRED, 0UL, ISCONFIRM),
	/* min         */ 0,
	/* max         */ 0,
	/* maxlen      */ MAXLEN_PSTR6,
	/* enumptr     */ NULL,
	/* collptr     */ NULL,
	/* totextptr   */ p80211_totext_octetstr,
	/* fromtextptr */ p80211_fromtext_octetstr,
	/* validfunptr */ p80211_isvalid_octetstr
},
{
	/* name        */ "ssid",
	/* did         */ P80211DID_MKID(0,0,0,0,0,0,P80211_TYPE_OCTETSTR),
	/* flags       */ P80211ITEM_SETFLAGS(ISREQUIRED, 0UL, ISCONFIRM),
	/* min         */ 0,
	/* max         */ 0,
	/* maxlen      */ MAXLEN_PSTR32,
	/* enumptr     */ NULL,
	/* collptr     */ NULL,
	/* totextptr   */ p80211_totext_octetstr,
	/* fromtextptr */ p80211_fromtext_octetstr,
	/* validfunptr */ p80211_isvalid_octetstr
},
{
	/* name        */ MKITEMNAME("bsstype"),
	/* did         */ P80211DID_MKID(0,0,0,0,0,0,P80211_TYPE_ENUMINT),
	/* flags       */ P80211ITEM_SETFLAGS(ISREQUIRED, 0UL, ISCONFIRM),
	/* min         */ 0,
	/* max         */ 0,
	/* maxlen      */ 0,
	/* enumptr     */ &MKENUMNAME(bsstype),
	/* collptr     */ NULL,
	/* totextptr   */ p80211_totext_enumint,
	/* fromtextptr */ p80211_fromtext_enumint,
	/* validfunptr */ p80211_isvalid_enumint
},
{
	/* name        */ MKITEMNAME("beaconperiod"),
	/* did         */ P80211DID_MKID(0,0,0,0,0,0,P80211_TYPE_INT),
	/* flags       */ P80211ITEM_SETFLAGS(ISREQUIRED, 0UL, ISCONFIRM),
	/* min         */ 0,
	/* max         */ 0,
	/* maxlen      */ 0,
	/* enumptr     */ NULL,
	/* collptr     */ NULL,
	/* totextptr   */ p80211_totext_int,
	/* fromtextptr */ p80211_fromtext_int,
	/* validfunptr */ p80211_isvalid_int
},
{
	/* name        */ MKITEMNAME("dtimperiod"),
	/* did         */ P80211DID_MKID(0,0,0,0,0,0,P80211_TYPE_BOUNDEDINT),
	/* flags       */ P80211ITEM_SETFLAGS(ISREQUIRED, 0UL, ISCONFIRM),
	/* min         */ 1,
	/* max         */ 255,
	/* maxlen      */ 0,
	/* enumptr     */ NULL,
	/* collptr     */ NULL,
	/* totextptr   */ p80211_totext_boundedint,
	/* fromtextptr */ p80211_fromtext_boundedint,
	/* validfunptr */ p80211_isvalid_boundedint
},
{
	/* name        */ MKITEMNAME("timestamp"),
	/* did         */ P80211DID_MKID(0,0,0,0,0,0,P80211_TYPE_INT),
	/* flags       */ P80211ITEM_SETFLAGS(ISREQUIRED, 0UL, ISCONFIRM),
	/* min         */ 0,
	/* max         */ 0,
	/* maxlen      */ 0,
	/* enumptr     */ NULL,
	/* collptr     */ NULL,
	/* totextptr   */ p80211_totext_int,
	/* fromtextptr */ p80211_fromtext_int,
	/* validfunptr */ p80211_isvalid_int
},
{
	/* name        */ MKITEMNAME("localtime"),
	/* did         */ P80211DID_MKID(0,0,0,0,0,0,P80211_TYPE_INT),
	/* flags       */ P80211ITEM_SETFLAGS(ISREQUIRED, 0UL, ISCONFIRM),
	/* min         */ 0,
	/* max         */ 0,
	/* maxlen      */ 0,
	/* enumptr     */ NULL,
	/* collptr     */ NULL,
	/* totextptr   */ p80211_totext_int,
	/* fromtextptr */ p80211_fromtext_int,
	/* validfunptr */ p80211_isvalid_int
},
{
	/* name        */ MKITEMNAME("fhdwelltime"),
	/* did         */ P80211DID_MKID(0,0,0,0,0,0,P80211_TYPE_BOUNDEDINT),
	/* flags       */ P80211ITEM_SETFLAGS(ISREQUIRED, 0UL, ISCONFIRM),
	/* min         */ 1,
	/* max         */ 65535,
	/* maxlen      */ 0,
	/* enumptr     */ NULL,
	/* collptr     */ NULL,
	/* totextptr   */ p80211_totext_boundedint,
	/* fromtextptr */ p80211_fromtext_boundedint,
	/* validfunptr */ p80211_isvalid_boundedint
},
{
	/* name        */ MKITEMNAME("fhhopset"),
	/* did         */ P80211DID_MKID(0,0,0,0,0,0,P80211_TYPE_BOUNDEDINT),
	/* flags       */ P80211ITEM_SETFLAGS(ISREQUIRED, 0UL, ISCONFIRM),
	/* min         */ 1,
	/* max         */ 255,
	/* maxlen      */ 0,
	/* enumptr     */ NULL,
	/* collptr     */ NULL,
	/* totextptr   */ p80211_totext_boundedint,
	/* fromtextptr */ p80211_fromtext_boundedint,
	/* validfunptr */ p80211_isvalid_boundedint
},
{
	/* name        */ MKITEMNAME("fhhoppattern"),
	/* did         */ P80211DID_MKID(0,0,0,0,0,0,P80211_TYPE_BOUNDEDINT),
	/* flags       */ P80211ITEM_SETFLAGS(ISREQUIRED, 0UL, ISCONFIRM),
	/* min         */ 0,
	/* max         */ 255,
	/* maxlen      */ 0,
	/* enumptr     */ NULL,
	/* collptr     */ NULL,
	/* totextptr   */ p80211_totext_boundedint,
	/* fromtextptr */ p80211_fromtext_boundedint,
	/* validfunptr */ p80211_isvalid_boundedint
},
{
	/* name        */ MKITEMNAME("fhhopindex"),
	/* did         */ P80211DID_MKID(0,0,0,0,0,0,P80211_TYPE_BOUNDEDINT),
	/* flags       */ P80211ITEM_SETFLAGS(ISREQUIRED, 0UL, ISCONFIRM),
	/* min         */ 1,
	/* max         */ 255,
	/* maxlen      */ 0,
	/* enumptr     */ NULL,
	/* collptr     */ NULL,
	/* totextptr   */ p80211_totext_boundedint,
	/* fromtextptr */ p80211_fromtext_boundedint,
	/* validfunptr */ p80211_isvalid_boundedint
},
{
	/* name        */ MKITEMNAME("dschannel"),
	/* did         */ P80211DID_MKID(0,0,0,0,0,0,P80211_TYPE_BOUNDEDINT),
	/* flags       */ P80211ITEM_SETFLAGS(ISREQUIRED, 0UL, ISCONFIRM),
	/* min         */ 1,
	/* max         */ 14,
	/* maxlen      */ 0,
	/* enumptr     */ NULL,
	/* collptr     */ NULL,
	/* totextptr   */ p80211_totext_boundedint,
	/* fromtextptr */ p80211_fromtext_boundedint,
	/* validfunptr */ p80211_isvalid_boundedint
},
{
	/* name        */ MKITEMNAME("cfpcount"),
	/* did         */ P80211DID_MKID(0,0,0,0,0,0,P80211_TYPE_INT),
	/* flags       */ P80211ITEM_SETFLAGS(ISREQUIRED, 0UL, ISCONFIRM),
	/* min         */ 0,
	/* max         */ 0,
	/* maxlen      */ 0,
	/* enumptr     */ NULL,
	/* collptr     */ NULL,
	/* totextptr   */ p80211_totext_int,
	/* fromtextptr */ p80211_fromtext_int,
	/* validfunptr */ p80211_isvalid_int
},
{
	/* name        */ MKITEMNAME("cfpperiod"),
	/* did         */ P80211DID_MKID(0,0,0,0,0,0,P80211_TYPE_BOUNDEDINT),
	/* flags       */ P80211ITEM_SETFLAGS(ISREQUIRED, 0UL, ISCONFIRM),
	/* min         */ 0,
	/* max         */ 255,
	/* maxlen      */ 0,
	/* enumptr     */ NULL,
	/* collptr     */ NULL,
	/* totextptr   */ p80211_totext_boundedint,
	/* fromtextptr */ p80211_fromtext_boundedint,
	/* validfunptr */ p80211_isvalid_boundedint
},
{
	/* name        */ MKITEMNAME("cfpmaxduration"),
	/* did         */ P80211DID_MKID(0,0,0,0,0,0,P80211_TYPE_BOUNDEDINT),
	/* flags       */ P80211ITEM_SETFLAGS(ISREQUIRED, 0UL, ISCONFIRM),
	/* min         */ 0,
	/* max         */ 65535,
	/* maxlen      */ 0,
	/* enumptr     */ NULL,
	/* collptr     */ NULL,
	/* totextptr   */ p80211_totext_boundedint,
	/* fromtextptr */ p80211_fromtext_boundedint,
	/* validfunptr */ p80211_isvalid_boundedint
},
{
	/* name        */ MKITEMNAME("cfpdurremaining"),
	/* did         */ P80211DID_MKID(0,0,0,0,0,0,P80211_TYPE_INT),
	/* flags       */ P80211ITEM_SETFLAGS(ISREQUIRED, 0UL, ISCONFIRM),
	/* min         */ 0,
	/* max         */ 0,
	/* maxlen      */ 0,
	/* enumptr     */ NULL,
	/* collptr     */ NULL,
	/* totextptr   */ p80211_totext_int,
	/* fromtextptr */ p80211_fromtext_int,
	/* validfunptr */ p80211_isvalid_int
},
{
	/* name        */ MKITEMNAME("ibssatimwindow"),
	/* did         */ P80211DID_MKID(0,0,0,0,0,0,P80211_TYPE_INT),
	/* flags       */ P80211ITEM_SETFLAGS(ISREQUIRED, 0UL, ISCONFIRM),
	/* min         */ 0,
	/* max         */ 0,
	/* maxlen      */ 0,
	/* enumptr     */ NULL,
	/* collptr     */ NULL,
	/* totextptr   */ p80211_totext_int,
	/* fromtextptr */ p80211_fromtext_int,
	/* validfunptr */ p80211_isvalid_int
},
{
	/* name        */ MKITEMNAME("cfpollable"),
	/* did         */ P80211DID_MKID(0,0,0,0,0,0,P80211_TYPE_ENUMINT),
	/* flags       */ P80211ITEM_SETFLAGS(ISREQUIRED, 0UL, ISCONFIRM),
	/* min         */ 0,
	/* max         */ 0,
	/* maxlen      */ 0,
	/* enumptr     */ &MKENUMNAME(truth),
	/* collptr     */ NULL,
	/* totextptr   */ p80211_totext_enumint,
	/* fromtextptr */ p80211_fromtext_enumint,
	/* validfunptr */ p80211_isvalid_enumint
},
{
	/* name        */ MKITEMNAME("cfpollreq"),
	/* did         */ P80211DID_MKID(0,0,0,0,0,0,P80211_TYPE_ENUMINT),
	/* flags       */ P80211ITEM_SETFLAGS(ISREQUIRED, 0UL, ISCONFIRM),
	/* min         */ 0,
	/* max         */ 0,
	/* maxlen      */ 0,
	/* enumptr     */ &MKENUMNAME(truth),
	/* collptr     */ NULL,
	/* totextptr   */ p80211_totext_enumint,
	/* fromtextptr */ p80211_fromtext_enumint,
	/* validfunptr */ p80211_isvalid_enumint
},
{
	/* name        */ MKITEMNAME("privacy"),
	/* did         */ P80211DID_MKID(0,0,0,0,0,0,P80211_TYPE_ENUMINT),
	/* flags       */ P80211ITEM_SETFLAGS(ISREQUIRED, 0UL, ISCONFIRM),
	/* min         */ 0,
	/* max         */ 0,
	/* maxlen      */ 0,
	/* enumptr     */ &MKENUMNAME(truth),
	/* collptr     */ NULL,
	/* totextptr   */ p80211_totext_enumint,
	/* fromtextptr */ p80211_fromtext_enumint,
	/* validfunptr */ p80211_isvalid_enumint
},
{
	/* name        */ MKITEMNAME("basicrate1"),
	/* did         */ P80211DID_MKID(0,0,0,0,0,0,P80211_TYPE_BOUNDEDINT),
	/* flags       */ P80211ITEM_SETFLAGS(ISREQUIRED, 0UL, ISCONFIRM),
	/* min         */ 2,
	/* max         */ 127,
	/* maxlen      */ 0,
	/* enumptr     */ NULL,
	/* collptr     */ NULL,
	/* totextptr   */ p80211_totext_boundedint,
	/* fromtextptr */ p80211_fromtext_boundedint,
	/* validfunptr */ p80211_isvalid_boundedint
},
{
	/* name        */ MKITEMNAME("basicrate2"),
	/* did         */ P80211DID_MKID(0,0,0,0,0,0,P80211_TYPE_BOUNDEDINT),
	/* flags       */ P80211ITEM_SETFLAGS(ISREQUIRED, 0UL, ISCONFIRM),
	/* min         */ 2,
	/* max         */ 127,
	/* maxlen      */ 0,
	/* enumptr     */ NULL,
	/* collptr     */ NULL,
	/* totextptr   */ p80211_totext_boundedint,
	/* fromtextptr */ p80211_fromtext_boundedint,
	/* validfunptr */ p80211_isvalid_boundedint
},
{
	/* name        */ MKITEMNAME("basicrate3"),
	/* did         */ P80211DID_MKID(0,0,0,0,0,0,P80211_TYPE_BOUNDEDINT),
	/* flags       */ P80211ITEM_SETFLAGS(ISREQUIRED, 0UL, ISCONFIRM),
	/* min         */ 2,
	/* max         */ 127,
	/* maxlen      */ 0,
	/* enumptr     */ NULL,
	/* collptr     */ NULL,
	/* totextptr   */ p80211_totext_boundedint,
	/* fromtextptr */ p80211_fromtext_boundedint,
	/* validfunptr */ p80211_isvalid_boundedint
},
{
	/* name        */ MKITEMNAME("basicrate4"),
	/* did         */ P80211DID_MKID(0,0,0,0,0,0,P80211_TYPE_BOUNDEDINT),
	/* flags       */ P80211ITEM_SETFLAGS(ISREQUIRED, 0UL, ISCONFIRM),
	/* min         */ 2,
	/* max         */ 127,
	/* maxlen      */ 0,
	/* enumptr     */ NULL,
	/* collptr     */ NULL,
	/* totextptr   */ p80211_totext_boundedint,
	/* fromtextptr */ p80211_fromtext_boundedint,
	/* validfunptr */ p80211_isvalid_boundedint
},
{
	/* name        */ MKITEMNAME("basicrate5"),
	/* did         */ P80211DID_MKID(0,0,0,0,0,0,P80211_TYPE_BOUNDEDINT),
	/* flags       */ P80211ITEM_SETFLAGS(ISREQUIRED, 0UL, ISCONFIRM),
	/* min         */ 2,
	/* max         */ 127,
	/* maxlen      */ 0,
	/* enumptr     */ NULL,
	/* collptr     */ NULL,
	/* totextptr   */ p80211_totext_boundedint,
	/* fromtextptr */ p80211_fromtext_boundedint,
	/* validfunptr */ p80211_isvalid_boundedint
},
{
	/* name        */ MKITEMNAME("basicrate6"),
	/* did         */ P80211DID_MKID(0,0,0,0,0,0,P80211_TYPE_BOUNDEDINT),
	/* flags       */ P80211ITEM_SETFLAGS(ISREQUIRED, 0UL, ISCONFIRM),
	/* min         */ 2,
	/* max         */ 127,
	/* maxlen      */ 0,
	/* enumptr     */ NULL,
	/* collptr     */ NULL,
	/* totextptr   */ p80211_totext_boundedint,
	/* fromtextptr */ p80211_fromtext_boundedint,
	/* validfunptr */ p80211_isvalid_boundedint
},
{
	/* name        */ MKITEMNAME("basicrate7"),
	/* did         */ P80211DID_MKID(0,0,0,0,0,0,P80211_TYPE_BOUNDEDINT),
	/* flags       */ P80211ITEM_SETFLAGS(ISREQUIRED, 0UL, ISCONFIRM),
	/* min         */ 2,
	/* max         */ 127,
	/* maxlen      */ 0,
	/* enumptr     */ NULL,
	/* collptr     */ NULL,
	/* totextptr   */ p80211_totext_boundedint,
	/* fromtextptr */ p80211_fromtext_boundedint,
	/* validfunptr */ p80211_isvalid_boundedint
},
{
	/* name        */ MKITEMNAME("basicrate8"),
	/* did         */ P80211DID_MKID(0,0,0,0,0,0,P80211_TYPE_BOUNDEDINT),
	/* flags       */ P80211ITEM_SETFLAGS(ISREQUIRED, 0UL, ISCONFIRM),
	/* min         */ 2,
	/* max         */ 127,
	/* maxlen      */ 0,
	/* enumptr     */ NULL,
	/* collptr     */ NULL,
	/* totextptr   */ p80211_totext_boundedint,
	/* fromtextptr */ p80211_fromtext_boundedint,
	/* validfunptr */ p80211_isvalid_boundedint
}
};  /* end of scan_results metadata list */

UINT32	MKREQMETASIZE(scan_results) = 
		sizeof(MKREQMETANAME(scan_results))/sizeof(p80211meta_t);

/*--------------------------------------------------------------------*/
/* metadata for the join request message arguments */

extern	UINT32	MKREQMETASIZE(join);

p80211meta_t MKREQMETANAME(join)[] = {
{
	/* name        */ (char *)&(MKREQMETASIZE(join)),
	/* did         */ 0,
	/* flags       */ 0,
	/* min         */ 0,
	/* max         */ 0,
	/* maxlen      */ 0,
	/* enumptr     */ NULL,
	/* collptr     */ NULL,
	/* totextptr   */ NULL,
	/* fromtextptr */ NULL,
	/* validfunptr */ NULL
},
{
	/* name        */ "bssid",
	/* did         */ P80211DID_MKID(0,0,0,0,0,0,P80211_TYPE_OCTETSTR),
	/* flags       */ P80211ITEM_SETFLAGS(ISREQUIRED, ISREQUEST, 0UL),
	/* min         */ 0,
	/* max         */ 0,
	/* maxlen      */ MAXLEN_PSTR6,
	/* enumptr     */ NULL,
	/* collptr     */ NULL,
	/* totextptr   */ p80211_totext_octetstr,
	/* fromtextptr */ p80211_fromtext_octetstr,
	/* validfunptr */ p80211_isvalid_octetstr
},
{
	/* name        */ "joinfailuretimeout",
	/* did         */ P80211DID_MKID(0,0,0,0,0,0,P80211_TYPE_BOUNDEDINT),
	/* flags       */ P80211ITEM_SETFLAGS(ISREQUIRED, ISREQUEST, 0UL),
	/* min         */ 1,
	/* max         */ UINT32_MAX,
	/* maxlen      */ 0,
	/* enumptr     */ NULL,
	/* collptr     */ NULL,
	/* totextptr   */ p80211_totext_boundedint,
	/* fromtextptr */ p80211_fromtext_boundedint,
	/* validfunptr */ p80211_isvalid_boundedint
},
{
	/* name        */ MKITEMNAME("basicrate1"),
	/* did         */ P80211DID_MKID(0,0,0,0,0,0,P80211_TYPE_BOUNDEDINT),
	/* flags       */ P80211ITEM_SETFLAGS(ISREQUIRED, ISREQUEST, 0UL),
	/* min         */ 2,
	/* max         */ 127,
	/* maxlen      */ 0,
	/* enumptr     */ NULL,
	/* collptr     */ NULL,
	/* totextptr   */ p80211_totext_boundedint,
	/* fromtextptr */ p80211_fromtext_boundedint,
	/* validfunptr */ p80211_isvalid_boundedint
},
{
	/* name        */ MKITEMNAME("basicrate2"),
	/* did         */ P80211DID_MKID(0,0,0,0,0,0,P80211_TYPE_BOUNDEDINT),
	/* flags       */ P80211ITEM_SETFLAGS(0UL, ISREQUEST, 0UL),
	/* min         */ 2,
	/* max         */ 127,
	/* maxlen      */ 0,
	/* enumptr     */ NULL,
	/* collptr     */ NULL,
	/* totextptr   */ p80211_totext_boundedint,
	/* fromtextptr */ p80211_fromtext_boundedint,
	/* validfunptr */ p80211_isvalid_boundedint
},
{
	/* name        */ MKITEMNAME("basicrate3"),
	/* did         */ P80211DID_MKID(0,0,0,0,0,0,P80211_TYPE_BOUNDEDINT),
	/* flags       */ P80211ITEM_SETFLAGS(0UL, ISREQUEST, 0UL),
	/* min         */ 2,
	/* max         */ 127,
	/* maxlen      */ 0,
	/* enumptr     */ NULL,
	/* collptr     */ NULL,
	/* totextptr   */ p80211_totext_boundedint,
	/* fromtextptr */ p80211_fromtext_boundedint,
	/* validfunptr */ p80211_isvalid_boundedint
},
{
	/* name        */ MKITEMNAME("basicrate4"),
	/* did         */ P80211DID_MKID(0,0,0,0,0,0,P80211_TYPE_BOUNDEDINT),
	/* flags       */ P80211ITEM_SETFLAGS(0UL, ISREQUEST, 0UL),
	/* min         */ 2,
	/* max         */ 127,
	/* maxlen      */ 0,
	/* enumptr     */ NULL,
	/* collptr     */ NULL,
	/* totextptr   */ p80211_totext_boundedint,
	/* fromtextptr */ p80211_fromtext_boundedint,
	/* validfunptr */ p80211_isvalid_boundedint
},
{
	/* name        */ MKITEMNAME("basicrate5"),
	/* did         */ P80211DID_MKID(0,0,0,0,0,0,P80211_TYPE_BOUNDEDINT),
	/* flags       */ P80211ITEM_SETFLAGS(0UL, ISREQUEST, 0UL),
	/* min         */ 2,
	/* max         */ 127,
	/* maxlen      */ 0,
	/* enumptr     */ NULL,
	/* collptr     */ NULL,
	/* totextptr   */ p80211_totext_boundedint,
	/* fromtextptr */ p80211_fromtext_boundedint,
	/* validfunptr */ p80211_isvalid_boundedint
},
{
	/* name        */ MKITEMNAME("basicrate6"),
	/* did         */ P80211DID_MKID(0,0,0,0,0,0,P80211_TYPE_BOUNDEDINT),
	/* flags       */ P80211ITEM_SETFLAGS(0UL, ISREQUEST, 0UL),
	/* min         */ 2,
	/* max         */ 127,
	/* maxlen      */ 0,
	/* enumptr     */ NULL,
	/* collptr     */ NULL,
	/* totextptr   */ p80211_totext_boundedint,
	/* fromtextptr */ p80211_fromtext_boundedint,
	/* validfunptr */ p80211_isvalid_boundedint
},
{
	/* name        */ MKITEMNAME("basicrate7"),
	/* did         */ P80211DID_MKID(0,0,0,0,0,0,P80211_TYPE_BOUNDEDINT),
	/* flags       */ P80211ITEM_SETFLAGS(0UL, ISREQUEST, 0UL),
	/* min         */ 2,
	/* max         */ 127,
	/* maxlen      */ 0,
	/* enumptr     */ NULL,
	/* collptr     */ NULL,
	/* totextptr   */ p80211_totext_boundedint,
	/* fromtextptr */ p80211_fromtext_boundedint,
	/* validfunptr */ p80211_isvalid_boundedint
},
{
	/* name        */ MKITEMNAME("basicrate8"),
	/* did         */ P80211DID_MKID(0,0,0,0,0,0,P80211_TYPE_BOUNDEDINT),
	/* flags       */ P80211ITEM_SETFLAGS(0UL, ISREQUEST, 0UL),
	/* min         */ 2,
	/* max         */ 127,
	/* maxlen      */ 0,
	/* enumptr     */ NULL,
	/* collptr     */ NULL,
	/* totextptr   */ p80211_totext_boundedint,
	/* fromtextptr */ p80211_fromtext_boundedint,
	/* validfunptr */ p80211_isvalid_boundedint
},
{
	/* name        */ MKITEMNAME("operationalrate1"),
	/* did         */ P80211DID_MKID(0,0,0,0,0,0,P80211_TYPE_BOUNDEDINT),
	/* flags       */ P80211ITEM_SETFLAGS(ISREQUIRED, ISREQUEST, 0UL),
	/* min         */ 2,
	/* max         */ 127,
	/* maxlen      */ 0,
	/* enumptr     */ NULL,
	/* collptr     */ NULL,
	/* totextptr   */ p80211_totext_boundedint,
	/* fromtextptr */ p80211_fromtext_boundedint,
	/* validfunptr */ p80211_isvalid_boundedint
},
{
	/* name        */ MKITEMNAME("operationalrate2"),
	/* did         */ P80211DID_MKID(0,0,0,0,0,0,P80211_TYPE_BOUNDEDINT),
	/* flags       */ P80211ITEM_SETFLAGS(0UL, ISREQUEST, 0UL),
	/* min         */ 2,
	/* max         */ 127,
	/* maxlen      */ 0,
	/* enumptr     */ NULL,
	/* collptr     */ NULL,
	/* totextptr   */ p80211_totext_boundedint,
	/* fromtextptr */ p80211_fromtext_boundedint,
	/* validfunptr */ p80211_isvalid_boundedint
},
{
	/* name        */ MKITEMNAME("operationalrate3"),
	/* did         */ P80211DID_MKID(0,0,0,0,0,0,P80211_TYPE_BOUNDEDINT),
	/* flags       */ P80211ITEM_SETFLAGS(0UL, ISREQUEST, 0UL),
	/* min         */ 2,
	/* max         */ 127,
	/* maxlen      */ 0,
	/* enumptr     */ NULL,
	/* collptr     */ NULL,
	/* totextptr   */ p80211_totext_boundedint,
	/* fromtextptr */ p80211_fromtext_boundedint,
	/* validfunptr */ p80211_isvalid_boundedint
},
{
	/* name        */ MKITEMNAME("operationalrate4"),
	/* did         */ P80211DID_MKID(0,0,0,0,0,0,P80211_TYPE_BOUNDEDINT),
	/* flags       */ P80211ITEM_SETFLAGS(0UL, ISREQUEST, 0UL),
	/* min         */ 2,
	/* max         */ 127,
	/* maxlen      */ 0,
	/* enumptr     */ NULL,
	/* collptr     */ NULL,
	/* totextptr   */ p80211_totext_boundedint,
	/* fromtextptr */ p80211_fromtext_boundedint,
	/* validfunptr */ p80211_isvalid_boundedint
},
{
	/* name        */ MKITEMNAME("operationalrate5"),
	/* did         */ P80211DID_MKID(0,0,0,0,0,0,P80211_TYPE_BOUNDEDINT),
	/* flags       */ P80211ITEM_SETFLAGS(0UL, ISREQUEST, 0UL),
	/* min         */ 2,
	/* max         */ 127,
	/* maxlen      */ 0,
	/* enumptr     */ NULL,
	/* collptr     */ NULL,
	/* totextptr   */ p80211_totext_boundedint,
	/* fromtextptr */ p80211_fromtext_boundedint,
	/* validfunptr */ p80211_isvalid_boundedint
},
{
	/* name        */ MKITEMNAME("operationalrate6"),
	/* did         */ P80211DID_MKID(0,0,0,0,0,0,P80211_TYPE_BOUNDEDINT),
	/* flags       */ P80211ITEM_SETFLAGS(0UL, ISREQUEST, 0UL),
	/* min         */ 2,
	/* max         */ 127,
	/* maxlen      */ 0,
	/* enumptr     */ NULL,
	/* collptr     */ NULL,
	/* totextptr   */ p80211_totext_boundedint,
	/* fromtextptr */ p80211_fromtext_boundedint,
	/* validfunptr */ p80211_isvalid_boundedint
},
{
	/* name        */ MKITEMNAME("operationalrate7"),
	/* did         */ P80211DID_MKID(0,0,0,0,0,0,P80211_TYPE_BOUNDEDINT),
	/* flags       */ P80211ITEM_SETFLAGS(0UL, ISREQUEST, 0UL),
	/* min         */ 2,
	/* max         */ 127,
	/* maxlen      */ 0,
	/* enumptr     */ NULL,
	/* collptr     */ NULL,
	/* totextptr   */ p80211_totext_boundedint,
	/* fromtextptr */ p80211_fromtext_boundedint,
	/* validfunptr */ p80211_isvalid_boundedint
},
{
	/* name        */ MKITEMNAME("operationalrate8"),
	/* did         */ P80211DID_MKID(0,0,0,0,0,0,P80211_TYPE_BOUNDEDINT),
	/* flags       */ P80211ITEM_SETFLAGS(0UL, ISREQUEST, 0UL),
	/* min         */ 2,
	/* max         */ 127,
	/* maxlen      */ 0,
	/* enumptr     */ NULL,
	/* collptr     */ NULL,
	/* totextptr   */ p80211_totext_boundedint,
	/* fromtextptr */ p80211_fromtext_boundedint,
	/* validfunptr */ p80211_isvalid_boundedint
},
{
	/* name        */ MKITEMNAME("resultcode"),
	/* did         */ P80211DID_MKID(0,0,0,0,0,0,P80211_TYPE_ENUMINT),
	/* flags       */ P80211ITEM_SETFLAGS(ISREQUIRED, 0UL, ISCONFIRM),
	/* min         */ 0,
	/* max         */ 0,
	/* maxlen      */ 0,
	/* enumptr     */ &MKENUMNAME(resultcode),
	/* collptr     */ NULL,
	/* totextptr   */ p80211_totext_enumint,
	/* fromtextptr */ p80211_fromtext_enumint,
	/* validfunptr */ p80211_isvalid_enumint
}
};  /* end of join request message metadata list */

UINT32	MKREQMETASIZE(join) = 
		sizeof(MKREQMETANAME(join))/sizeof(p80211meta_t);

/*--------------------------------------------------------------------*/
/* metadata for the authenticate request message arguments */

extern	UINT32	MKREQMETASIZE(authenticate);

p80211meta_t MKREQMETANAME(authenticate)[] = {
{
	/* name        */ (char *)&(MKREQMETASIZE(authenticate)),
	/* did         */ 0,
	/* flags       */ 0,
	/* min         */ 0,
	/* max         */ 0,
	/* maxlen      */ 0,
	/* enumptr     */ NULL,
	/* collptr     */ NULL,
	/* totextptr   */ NULL,
	/* fromtextptr */ NULL,
	/* validfunptr */ NULL
},
{
	/* name        */ "peerstaaddress",
	/* did         */ P80211DID_MKID(0,0,0,0,0,0,P80211_TYPE_OCTETSTR),
	/* flags       */ P80211ITEM_SETFLAGS(ISREQUIRED, ISREQUEST, ISCONFIRM),
	/* min         */ 0,
	/* max         */ 0,
	/* maxlen      */ MAXLEN_PSTR6,
	/* enumptr     */ NULL,
	/* collptr     */ NULL,
	/* totextptr   */ p80211_totext_octetstr,
	/* fromtextptr */ p80211_fromtext_octetstr,
	/* validfunptr */ p80211_isvalid_octetstr
},
{
	/* name        */ MKITEMNAME("authenticationtype"),
	/* did         */ P80211DID_MKID(0,0,0,0,0,0,P80211_TYPE_ENUMINT),
	/* flags       */ P80211ITEM_SETFLAGS(ISREQUIRED, ISREQUEST, ISCONFIRM),
	/* min         */ 0,
	/* max         */ 0,
	/* maxlen      */ 0,
	/* enumptr     */ &MKENUMNAME(authalg),
	/* collptr     */ NULL,
	/* totextptr   */ p80211_totext_enumint,
	/* fromtextptr */ p80211_fromtext_enumint,
	/* validfunptr */ p80211_isvalid_enumint
},
{
	/* name        */ "authenticationfailuretimeout",
	/* did         */ P80211DID_MKID(0,0,0,0,0,0,P80211_TYPE_BOUNDEDINT),
	/* flags       */ P80211ITEM_SETFLAGS(ISREQUIRED, ISREQUEST, 0UL),
	/* min         */ 1,
	/* max         */ UINT32_MAX,
	/* maxlen      */ 0,
	/* enumptr     */ NULL,
	/* collptr     */ NULL,
	/* totextptr   */ p80211_totext_boundedint,
	/* fromtextptr */ p80211_fromtext_boundedint,
	/* validfunptr */ p80211_isvalid_boundedint
},
{
	/* name        */ MKITEMNAME("resultcode"),
	/* did         */ P80211DID_MKID(0,0,0,0,0,0,P80211_TYPE_ENUMINT),
	/* flags       */ P80211ITEM_SETFLAGS(ISREQUIRED, 0UL, ISCONFIRM),
	/* min         */ 0,
	/* max         */ 0,
	/* maxlen      */ 0,
	/* enumptr     */ &MKENUMNAME(resultcode),
	/* collptr     */ NULL,
	/* totextptr   */ p80211_totext_enumint,
	/* fromtextptr */ p80211_fromtext_enumint,
	/* validfunptr */ p80211_isvalid_enumint
}
};  /* end of authenticate request message metadata list */

UINT32	MKREQMETASIZE(authenticate) = 
		sizeof(MKREQMETANAME(authenticate))/sizeof(p80211meta_t);

/*--------------------------------------------------------------------*/
/* metadata for the deauthenticate request message arguments */

extern	UINT32	MKREQMETASIZE(deauthenticate);

p80211meta_t MKREQMETANAME(deauthenticate)[] = {
{
	/* name        */ (char *)&(MKREQMETASIZE(deauthenticate)),
	/* did         */ 0,
	/* flags       */ 0,
	/* min         */ 0,
	/* max         */ 0,
	/* maxlen      */ 0,
	/* enumptr     */ NULL,
	/* collptr     */ NULL,
	/* totextptr   */ NULL,
	/* fromtextptr */ NULL,
	/* validfunptr */ NULL
},
{
	/* name        */ "peerstaaddress",
	/* did         */ P80211DID_MKID(0,0,0,0,0,0,P80211_TYPE_OCTETSTR),
	/* flags       */ P80211ITEM_SETFLAGS(ISREQUIRED, ISREQUEST, ISCONFIRM),
	/* min         */ 0,
	/* max         */ 0,
	/* maxlen      */ MAXLEN_PSTR6,
	/* enumptr     */ NULL,
	/* collptr     */ NULL,
	/* totextptr   */ p80211_totext_octetstr,
	/* fromtextptr */ p80211_fromtext_octetstr,
	/* validfunptr */ p80211_isvalid_octetstr
},
{
	/* name        */ MKITEMNAME("reasoncode"),
	/* did         */ P80211DID_MKID(0,0,0,0,0,0,P80211_TYPE_ENUMINT),
	/* flags       */ P80211ITEM_SETFLAGS(ISREQUIRED, ISREQUEST, 0UL),
	/* min         */ 0,
	/* max         */ 0,
	/* maxlen      */ 0,
	/* enumptr     */ &MKENUMNAME(reason),
	/* collptr     */ NULL,
	/* totextptr   */ p80211_totext_enumint,
	/* fromtextptr */ p80211_fromtext_enumint,
	/* validfunptr */ p80211_isvalid_enumint
},
{
	/* name        */ MKITEMNAME("resultcode"),
	/* did         */ P80211DID_MKID(0,0,0,0,0,0,P80211_TYPE_ENUMINT),
	/* flags       */ P80211ITEM_SETFLAGS(ISREQUIRED, 0UL, ISCONFIRM),
	/* min         */ 0,
	/* max         */ 0,
	/* maxlen      */ 0,
	/* enumptr     */ &MKENUMNAME(resultcode),
	/* collptr     */ NULL,
	/* totextptr   */ p80211_totext_enumint,
	/* fromtextptr */ p80211_fromtext_enumint,
	/* validfunptr */ p80211_isvalid_enumint
}
};  /* end of deauthenticate request message metadata list */

UINT32	MKREQMETASIZE(deauthenticate) = 
		sizeof(MKREQMETANAME(deauthenticate))/sizeof(p80211meta_t);

/*--------------------------------------------------------------------*/
/* metadata for the associate request message arguments */

extern	UINT32	MKREQMETASIZE(associate);

p80211meta_t MKREQMETANAME(associate)[] = {
{
	/* name        */ (char *)&(MKREQMETASIZE(associate)),
	/* did         */ 0,
	/* flags       */ 0,
	/* min         */ 0,
	/* max         */ 0,
	/* maxlen      */ 0,
	/* enumptr     */ NULL,
	/* collptr     */ NULL,
	/* totextptr   */ NULL,
	/* fromtextptr */ NULL,
	/* validfunptr */ NULL
},
{
	/* name        */ "peerstaaddress",
	/* did         */ P80211DID_MKID(0,0,0,0,0,0,P80211_TYPE_OCTETSTR),
	/* flags       */ P80211ITEM_SETFLAGS(0UL, ISREQUEST, 0UL),
	/* min         */ 0,
	/* max         */ 0,
	/* maxlen      */ MAXLEN_PSTR6,
	/* enumptr     */ NULL,
	/* collptr     */ NULL,
	/* totextptr   */ p80211_totext_octetstr,
	/* fromtextptr */ p80211_fromtext_octetstr,
	/* validfunptr */ p80211_isvalid_octetstr
},
{
	/* name        */ "associatefailuretimeout",
	/* did         */ P80211DID_MKID(0,0,0,0,0,0,P80211_TYPE_BOUNDEDINT),
	/* flags       */ P80211ITEM_SETFLAGS(0UL, ISREQUEST, 0UL),
	/* min         */ 1,
	/* max         */ UINT32_MAX,
	/* maxlen      */ 0,
	/* enumptr     */ NULL,
	/* collptr     */ NULL,
	/* totextptr   */ p80211_totext_boundedint,
	/* fromtextptr */ p80211_fromtext_boundedint,
	/* validfunptr */ p80211_isvalid_boundedint
},
{
	/* name        */ MKITEMNAME("cfpollable"),
	/* did         */ P80211DID_MKID(0,0,0,0,0,0,P80211_TYPE_ENUMINT),
	/* flags       */ P80211ITEM_SETFLAGS(0UL, ISREQUEST, 0UL),
	/* min         */ 0,
	/* max         */ 0,
	/* maxlen      */ 0,
	/* enumptr     */ &MKENUMNAME(truth),
	/* collptr     */ NULL,
	/* totextptr   */ p80211_totext_enumint,
	/* fromtextptr */ p80211_fromtext_enumint,
	/* validfunptr */ p80211_isvalid_enumint
},
{
	/* name        */ MKITEMNAME("cfpollreq"),
	/* did         */ P80211DID_MKID(0,0,0,0,0,0,P80211_TYPE_ENUMINT),
	/* flags       */ P80211ITEM_SETFLAGS(0UL, ISREQUEST, 0UL),
	/* min         */ 0,
	/* max         */ 0,
	/* maxlen      */ 0,
	/* enumptr     */ &MKENUMNAME(truth),
	/* collptr     */ NULL,
	/* totextptr   */ p80211_totext_enumint,
	/* fromtextptr */ p80211_fromtext_enumint,
	/* validfunptr */ p80211_isvalid_enumint
},
{
	/* name        */ MKITEMNAME("privacy"),
	/* did         */ P80211DID_MKID(0,0,0,0,0,0,P80211_TYPE_ENUMINT),
	/* flags       */ P80211ITEM_SETFLAGS(0UL, ISREQUEST, 0UL),
	/* min         */ 0,
	/* max         */ 0,
	/* maxlen      */ 0,
	/* enumptr     */ &MKENUMNAME(truth),
	/* collptr     */ NULL,
	/* totextptr   */ p80211_totext_enumint,
	/* fromtextptr */ p80211_fromtext_enumint,
	/* validfunptr */ p80211_isvalid_enumint
},
{
	/* name        */ MKITEMNAME("listeninterval"),
	/* did         */ P80211DID_MKID(0,0,0,0,0,0,P80211_TYPE_INT),
	/* flags       */ P80211ITEM_SETFLAGS(ISREQUIRED, ISREQUEST, 0UL),
	/* min         */ 0,
	/* max         */ 0,
	/* maxlen      */ 0,
	/* enumptr     */ NULL,
	/* collptr     */ NULL,
	/* totextptr   */ p80211_totext_int,
	/* fromtextptr */ p80211_fromtext_int,
	/* validfunptr */ p80211_isvalid_int
},
{
	/* name        */ MKITEMNAME("resultcode"),
	/* did         */ P80211DID_MKID(0,0,0,0,0,0,P80211_TYPE_ENUMINT),
	/* flags       */ P80211ITEM_SETFLAGS(ISREQUIRED, 0UL, ISCONFIRM),
	/* min         */ 0,
	/* max         */ 0,
	/* maxlen      */ 0,
	/* enumptr     */ &MKENUMNAME(resultcode),
	/* collptr     */ NULL,
	/* totextptr   */ p80211_totext_enumint,
	/* fromtextptr */ p80211_fromtext_enumint,
	/* validfunptr */ p80211_isvalid_enumint
}
};  /* end of associate request message metadata list */

UINT32	MKREQMETASIZE(associate) = 
		sizeof(MKREQMETANAME(associate))/sizeof(p80211meta_t);

/*--------------------------------------------------------------------*/
/* metadata for the reassociate request message arguments */

extern	UINT32	MKREQMETASIZE(reassociate);

p80211meta_t MKREQMETANAME(reassociate)[] = {
{
	/* name        */ (char *)&(MKREQMETASIZE(reassociate)),
	/* did         */ 0,
	/* flags       */ 0,
	/* min         */ 0,
	/* max         */ 0,
	/* maxlen      */ 0,
	/* enumptr     */ NULL,
	/* collptr     */ NULL,
	/* totextptr   */ NULL,
	/* fromtextptr */ NULL,
	/* validfunptr */ NULL
},
{
	/* name        */ "newapaddress",
	/* did         */ P80211DID_MKID(0,0,0,0,0,0,P80211_TYPE_OCTETSTR),
	/* flags       */ P80211ITEM_SETFLAGS(ISREQUIRED, ISREQUEST, 0UL),
	/* min         */ 0,
	/* max         */ 0,
	/* maxlen      */ MAXLEN_PSTR6,
	/* enumptr     */ NULL,
	/* collptr     */ NULL,
	/* totextptr   */ p80211_totext_octetstr,
	/* fromtextptr */ p80211_fromtext_octetstr,
	/* validfunptr */ p80211_isvalid_octetstr
},
{
	/* name        */ "reassociatefailuretimeout",
	/* did         */ P80211DID_MKID(0,0,0,0,0,0,P80211_TYPE_BOUNDEDINT),
	/* flags       */ P80211ITEM_SETFLAGS(ISREQUIRED, ISREQUEST, 0UL),
	/* min         */ 1,
	/* max         */ UINT32_MAX,
	/* maxlen      */ 0,
	/* enumptr     */ NULL,
	/* collptr     */ NULL,
	/* totextptr   */ p80211_totext_boundedint,
	/* fromtextptr */ p80211_fromtext_boundedint,
	/* validfunptr */ p80211_isvalid_boundedint
},
{
	/* name        */ MKITEMNAME("cfpollable"),
	/* did         */ P80211DID_MKID(0,0,0,0,0,0,P80211_TYPE_ENUMINT),
	/* flags       */ P80211ITEM_SETFLAGS(ISREQUIRED, ISREQUEST, 0UL),
	/* min         */ 0,
	/* max         */ 0,
	/* maxlen      */ 0,
	/* enumptr     */ &MKENUMNAME(truth),
	/* collptr     */ NULL,
	/* totextptr   */ p80211_totext_enumint,
	/* fromtextptr */ p80211_fromtext_enumint,
	/* validfunptr */ p80211_isvalid_enumint
},
{
	/* name        */ MKITEMNAME("cfpollreq"),
	/* did         */ P80211DID_MKID(0,0,0,0,0,0,P80211_TYPE_ENUMINT),
	/* flags       */ P80211ITEM_SETFLAGS(ISREQUIRED, ISREQUEST, 0UL),
	/* min         */ 0,
	/* max         */ 0,
	/* maxlen      */ 0,
	/* enumptr     */ &MKENUMNAME(truth),
	/* collptr     */ NULL,
	/* totextptr   */ p80211_totext_enumint,
	/* fromtextptr */ p80211_fromtext_enumint,
	/* validfunptr */ p80211_isvalid_enumint
},
{
	/* name        */ MKITEMNAME("privacy"),
	/* did         */ P80211DID_MKID(0,0,0,0,0,0,P80211_TYPE_ENUMINT),
	/* flags       */ P80211ITEM_SETFLAGS(ISREQUIRED, ISREQUEST, 0UL),
	/* min         */ 0,
	/* max         */ 0,
	/* maxlen      */ 0,
	/* enumptr     */ &MKENUMNAME(truth),
	/* collptr     */ NULL,
	/* totextptr   */ p80211_totext_enumint,
	/* fromtextptr */ p80211_fromtext_enumint,
	/* validfunptr */ p80211_isvalid_enumint
},
{
	/* name        */ MKITEMNAME("listeninterval"),
	/* did         */ P80211DID_MKID(0,0,0,0,0,0,P80211_TYPE_INT),
	/* flags       */ P80211ITEM_SETFLAGS(ISREQUIRED, ISREQUEST, 0UL),
	/* min         */ 0,
	/* max         */ 0,
	/* maxlen      */ 0,
	/* enumptr     */ NULL,
	/* collptr     */ NULL,
	/* totextptr   */ p80211_totext_int,
	/* fromtextptr */ p80211_fromtext_int,
	/* validfunptr */ p80211_isvalid_int
},
{
	/* name        */ MKITEMNAME("resultcode"),
	/* did         */ P80211DID_MKID(0,0,0,0,0,0,P80211_TYPE_ENUMINT),
	/* flags       */ P80211ITEM_SETFLAGS(ISREQUIRED, 0UL, ISCONFIRM),
	/* min         */ 0,
	/* max         */ 0,
	/* maxlen      */ 0,
	/* enumptr     */ &MKENUMNAME(resultcode),
	/* collptr     */ NULL,
	/* totextptr   */ p80211_totext_enumint,
	/* fromtextptr */ p80211_fromtext_enumint,
	/* validfunptr */ p80211_isvalid_enumint
}
};  /* end of reassociate request message metadata list */

UINT32	MKREQMETASIZE(reassociate) = sizeof(MKREQMETANAME(reassociate))/sizeof(p80211meta_t);

/*--------------------------------------------------------------------*/
/* metadata for the disassociate request message arguments */

extern	UINT32	MKREQMETASIZE(disassociate);

p80211meta_t MKREQMETANAME(disassociate)[] = {
{
	/* name        */ (char *)&(MKREQMETASIZE(disassociate)),
	/* did         */ 0,
	/* flags       */ 0,
	/* min         */ 0,
	/* max         */ 0,
	/* maxlen      */ 0,
	/* enumptr     */ NULL,
	/* collptr     */ NULL,
	/* totextptr   */ NULL,
	/* fromtextptr */ NULL,
	/* validfunptr */ NULL
},
{
	/* name        */ "peerstaaddress",
	/* did         */ P80211DID_MKID(0,0,0,0,0,0,P80211_TYPE_OCTETSTR),
	/* flags       */ P80211ITEM_SETFLAGS(ISREQUIRED, ISREQUEST, ISCONFIRM),
	/* min         */ 0,
	/* max         */ 0,
	/* maxlen      */ MAXLEN_PSTR6,
	/* enumptr     */ NULL,
	/* collptr     */ NULL,
	/* totextptr   */ p80211_totext_octetstr,
	/* fromtextptr */ p80211_fromtext_octetstr,
	/* validfunptr */ p80211_isvalid_octetstr
},
{
	/* name        */ MKITEMNAME("reasoncode"),
	/* did         */ P80211DID_MKID(0,0,0,0,0,0,P80211_TYPE_ENUMINT),
	/* flags       */ P80211ITEM_SETFLAGS(ISREQUIRED, ISREQUEST, 0UL),
	/* min         */ 0,
	/* max         */ 0,
	/* maxlen      */ 0,
	/* enumptr     */ &MKENUMNAME(reason),
	/* collptr     */ NULL,
	/* totextptr   */ p80211_totext_enumint,
	/* fromtextptr */ p80211_fromtext_enumint,
	/* validfunptr */ p80211_isvalid_enumint
},
{
	/* name        */ MKITEMNAME("resultcode"),
	/* did         */ P80211DID_MKID(0,0,0,0,0,0,P80211_TYPE_ENUMINT),
	/* flags       */ P80211ITEM_SETFLAGS(ISREQUIRED, 0UL, ISCONFIRM),
	/* min         */ 0,
	/* max         */ 0,
	/* maxlen      */ 0,
	/* enumptr     */ &MKENUMNAME(resultcode),
	/* collptr     */ NULL,
	/* totextptr   */ p80211_totext_enumint,
	/* fromtextptr */ p80211_fromtext_enumint,
	/* validfunptr */ p80211_isvalid_enumint
}
};  /* end of disassociate request message metadata list */

UINT32	MKREQMETASIZE(disassociate) = sizeof(MKREQMETANAME(disassociate))/sizeof(p80211meta_t);

/*--------------------------------------------------------------------*/
/* metadata for the start request message arguments */

extern	UINT32	MKREQMETASIZE(start);

p80211meta_t MKREQMETANAME(start)[] = {
{
	/* name        */ (char *)&(MKREQMETASIZE(start)),
	/* did         */ 0,
	/* flags       */ 0,
	/* min         */ 0,
	/* max         */ 0,
	/* maxlen      */ 0,
	/* enumptr     */ NULL,
	/* collptr     */ NULL,
	/* totextptr   */ NULL,
	/* fromtextptr */ NULL,
	/* validfunptr */ NULL
},
{
	/* name        */ "ssid",
	/* did         */ P80211DID_MKID(0,0,0,0,0,0,P80211_TYPE_OCTETSTR),
	/* flags       */ P80211ITEM_SETFLAGS(ISREQUIRED, ISREQUEST, 0UL),
	/* min         */ 0,
	/* max         */ 0,
	/* maxlen      */ MAXLEN_PSTR32,
	/* enumptr     */ NULL,
	/* collptr     */ NULL,
	/* totextptr   */ p80211_totext_octetstr,
	/* fromtextptr */ p80211_fromtext_octetstr,
	/* validfunptr */ p80211_isvalid_octetstr
},
{
	/* name        */ MKITEMNAME("bsstype"),
	/* did         */ P80211DID_MKID(0,0,0,0,0,0,P80211_TYPE_ENUMINT),
	/* flags       */ P80211ITEM_SETFLAGS(ISREQUIRED, ISREQUEST, 0UL),
	/* min         */ 0,
	/* max         */ 0,
	/* maxlen      */ 0,
	/* enumptr     */ &MKENUMNAME(bsstype),
	/* collptr     */ NULL,
	/* totextptr   */ p80211_totext_enumint,
	/* fromtextptr */ p80211_fromtext_enumint,
	/* validfunptr */ p80211_isvalid_enumint
},
{
	/* name        */ MKITEMNAME("beaconperiod"),
	/* did         */ P80211DID_MKID(0,0,0,0,0,0,P80211_TYPE_BOUNDEDINT),
	/* flags       */ P80211ITEM_SETFLAGS(ISREQUIRED, ISREQUEST, 0UL),
	/* min         */ 1,
	/* max         */ 65535,
	/* maxlen      */ 0,
	/* enumptr     */ NULL,
	/* collptr     */ NULL,
	/* totextptr   */ p80211_totext_boundedint,
	/* fromtextptr */ p80211_fromtext_boundedint,
	/* validfunptr */ p80211_isvalid_boundedint
},
{
	/* name        */ MKITEMNAME("dtimperiod"),
	/* did         */ P80211DID_MKID(0,0,0,0,0,0,P80211_TYPE_BOUNDEDINT),
	/* flags       */ P80211ITEM_SETFLAGS(ISREQUIRED, ISREQUEST, 0UL),
	/* min         */ 1,
	/* max         */ 255,
	/* maxlen      */ 0,
	/* enumptr     */ NULL,
	/* collptr     */ NULL,
	/* totextptr   */ p80211_totext_boundedint,
	/* fromtextptr */ p80211_fromtext_boundedint,
	/* validfunptr */ p80211_isvalid_boundedint
},
{
	/* name        */ MKITEMNAME("cfpperiod"),
	/* did         */ P80211DID_MKID(0,0,0,0,0,0,P80211_TYPE_BOUNDEDINT),
	/* flags       */ P80211ITEM_SETFLAGS(0UL, ISREQUEST, 0UL),
	/* min         */ 0,
	/* max         */ 255,
	/* maxlen      */ 0,
	/* enumptr     */ NULL,
	/* collptr     */ NULL,
	/* totextptr   */ p80211_totext_boundedint,
	/* fromtextptr */ p80211_fromtext_boundedint,
	/* validfunptr */ p80211_isvalid_boundedint
},
{
	/* name        */ MKITEMNAME("cfpmaxduration"),
	/* did         */ P80211DID_MKID(0,0,0,0,0,0,P80211_TYPE_BOUNDEDINT),
	/* flags       */ P80211ITEM_SETFLAGS(0UL, ISREQUEST, 0UL),
	/* min         */ 0,
	/* max         */ 65535,
	/* maxlen      */ 0,
	/* enumptr     */ NULL,
	/* collptr     */ NULL,
	/* totextptr   */ p80211_totext_boundedint,
	/* fromtextptr */ p80211_fromtext_boundedint,
	/* validfunptr */ p80211_isvalid_boundedint
},
{
	/* name        */ MKITEMNAME("fhdwelltime"),
	/* did         */ P80211DID_MKID(0,0,0,0,0,0,P80211_TYPE_BOUNDEDINT),
	/* flags       */ P80211ITEM_SETFLAGS(0UL, ISREQUEST, 0UL),
	/* min         */ 1,
	/* max         */ 65535,
	/* maxlen      */ 0,
	/* enumptr     */ NULL,
	/* collptr     */ NULL,
	/* totextptr   */ p80211_totext_boundedint,
	/* fromtextptr */ p80211_fromtext_boundedint,
	/* validfunptr */ p80211_isvalid_boundedint
},
{
	/* name        */ MKITEMNAME("fhhopset"),
	/* did         */ P80211DID_MKID(0,0,0,0,0,0,P80211_TYPE_BOUNDEDINT),
	/* flags       */ P80211ITEM_SETFLAGS(0UL, ISREQUEST, 0UL),
	/* min         */ 1,
	/* max         */ 255,
	/* maxlen      */ 0,
	/* enumptr     */ NULL,
	/* collptr     */ NULL,
	/* totextptr   */ p80211_totext_boundedint,
	/* fromtextptr */ p80211_fromtext_boundedint,
	/* validfunptr */ p80211_isvalid_boundedint
},
{
	/* name        */ MKITEMNAME("fhhoppattern"),
	/* did         */ P80211DID_MKID(0,0,0,0,0,0,P80211_TYPE_BOUNDEDINT),
	/* flags       */ P80211ITEM_SETFLAGS(0UL, ISREQUEST, 0UL),
	/* min         */ 0,
	/* max         */ 255,
	/* maxlen      */ 0,
	/* enumptr     */ NULL,
	/* collptr     */ NULL,
	/* totextptr   */ p80211_totext_boundedint,
	/* fromtextptr */ p80211_fromtext_boundedint,
	/* validfunptr */ p80211_isvalid_boundedint
},
{
	/* name        */ MKITEMNAME("dschannel"),
	/* did         */ P80211DID_MKID(0,0,0,0,0,0,P80211_TYPE_BOUNDEDINT),
	/* flags       */ P80211ITEM_SETFLAGS(0UL, ISREQUEST, 0UL),
	/* min         */ 1,
	/* max         */ 14,
	/* maxlen      */ 0,
	/* enumptr     */ NULL,
	/* collptr     */ NULL,
	/* totextptr   */ p80211_totext_boundedint,
	/* fromtextptr */ p80211_fromtext_boundedint,
	/* validfunptr */ p80211_isvalid_boundedint
},
{
	/* name        */ MKITEMNAME("ibssatimwindow"),
	/* did         */ P80211DID_MKID(0,0,0,0,0,0,P80211_TYPE_INT),
	/* flags       */ P80211ITEM_SETFLAGS(0UL, ISREQUEST, 0UL),
	/* min         */ 0,
	/* max         */ 0,
	/* maxlen      */ 0,
	/* enumptr     */ NULL,
	/* collptr     */ NULL,
	/* totextptr   */ p80211_totext_int,
	/* fromtextptr */ p80211_fromtext_int,
	/* validfunptr */ p80211_isvalid_int
},
{
	/* name        */ MKITEMNAME("probedelay"),
	/* did         */ P80211DID_MKID(0,0,0,0,0,0,P80211_TYPE_INT),
	/* flags       */ P80211ITEM_SETFLAGS(ISREQUIRED, ISREQUEST, 0UL),
	/* min         */ 0,
	/* max         */ 0,
	/* maxlen      */ 0,
	/* enumptr     */ NULL,
	/* collptr     */ NULL,
	/* totextptr   */ p80211_totext_int,
	/* fromtextptr */ p80211_fromtext_int,
	/* validfunptr */ p80211_isvalid_int
},
{
	/* name        */ MKITEMNAME("cfpollable"),
	/* did         */ P80211DID_MKID(0,0,0,0,0,0,P80211_TYPE_ENUMINT),
	/* flags       */ P80211ITEM_SETFLAGS(ISREQUIRED, ISREQUEST, 0UL),
	/* min         */ 0,
	/* max         */ 0,
	/* maxlen      */ 0,
	/* enumptr     */ &MKENUMNAME(truth),
	/* collptr     */ NULL,
	/* totextptr   */ p80211_totext_enumint,
	/* fromtextptr */ p80211_fromtext_enumint,
	/* validfunptr */ p80211_isvalid_enumint
},
{
	/* name        */ MKITEMNAME("cfpollreq"),
	/* did         */ P80211DID_MKID(0,0,0,0,0,0,P80211_TYPE_ENUMINT),
	/* flags       */ P80211ITEM_SETFLAGS(ISREQUIRED, ISREQUEST, 0UL),
	/* min         */ 0,
	/* max         */ 0,
	/* maxlen      */ 0,
	/* enumptr     */ &MKENUMNAME(truth),
	/* collptr     */ NULL,
	/* totextptr   */ p80211_totext_enumint,
	/* fromtextptr */ p80211_fromtext_enumint,
	/* validfunptr */ p80211_isvalid_enumint
},
{
	/* name        */ MKITEMNAME("basicrate1"),
	/* did         */ P80211DID_MKID(0,0,0,0,0,0,P80211_TYPE_BOUNDEDINT),
	/* flags       */ P80211ITEM_SETFLAGS(ISREQUIRED, ISREQUEST, 0UL),
	/* min         */ 2,
	/* max         */ 127,
	/* maxlen      */ 0,
	/* enumptr     */ NULL,
	/* collptr     */ NULL,
	/* totextptr   */ p80211_totext_boundedint,
	/* fromtextptr */ p80211_fromtext_boundedint,
	/* validfunptr */ p80211_isvalid_boundedint
},
{
	/* name        */ MKITEMNAME("basicrate2"),
	/* did         */ P80211DID_MKID(0,0,0,0,0,0,P80211_TYPE_BOUNDEDINT),
	/* flags       */ P80211ITEM_SETFLAGS(0UL, ISREQUEST, 0UL),
	/* min         */ 2,
	/* max         */ 127,
	/* maxlen      */ 0,
	/* enumptr     */ NULL,
	/* collptr     */ NULL,
	/* totextptr   */ p80211_totext_boundedint,
	/* fromtextptr */ p80211_fromtext_boundedint,
	/* validfunptr */ p80211_isvalid_boundedint
},
{
	/* name        */ MKITEMNAME("basicrate3"),
	/* did         */ P80211DID_MKID(0,0,0,0,0,0,P80211_TYPE_BOUNDEDINT),
	/* flags       */ P80211ITEM_SETFLAGS(0UL, ISREQUEST, 0UL),
	/* min         */ 2,
	/* max         */ 127,
	/* maxlen      */ 0,
	/* enumptr     */ NULL,
	/* collptr     */ NULL,
	/* totextptr   */ p80211_totext_boundedint,
	/* fromtextptr */ p80211_fromtext_boundedint,
	/* validfunptr */ p80211_isvalid_boundedint
},
{
	/* name        */ MKITEMNAME("basicrate4"),
	/* did         */ P80211DID_MKID(0,0,0,0,0,0,P80211_TYPE_BOUNDEDINT),
	/* flags       */ P80211ITEM_SETFLAGS(0UL, ISREQUEST, 0UL),
	/* min         */ 2,
	/* max         */ 127,
	/* maxlen      */ 0,
	/* enumptr     */ NULL,
	/* collptr     */ NULL,
	/* totextptr   */ p80211_totext_boundedint,
	/* fromtextptr */ p80211_fromtext_boundedint,
	/* validfunptr */ p80211_isvalid_boundedint
},
{
	/* name        */ MKITEMNAME("basicrate5"),
	/* did         */ P80211DID_MKID(0,0,0,0,0,0,P80211_TYPE_BOUNDEDINT),
	/* flags       */ P80211ITEM_SETFLAGS(0UL, ISREQUEST, 0UL),
	/* min         */ 2,
	/* max         */ 127,
	/* maxlen      */ 0,
	/* enumptr     */ NULL,
	/* collptr     */ NULL,
	/* totextptr   */ p80211_totext_boundedint,
	/* fromtextptr */ p80211_fromtext_boundedint,
	/* validfunptr */ p80211_isvalid_boundedint
},
{
	/* name        */ MKITEMNAME("basicrate6"),
	/* did         */ P80211DID_MKID(0,0,0,0,0,0,P80211_TYPE_BOUNDEDINT),
	/* flags       */ P80211ITEM_SETFLAGS(0UL, ISREQUEST, 0UL),
	/* min         */ 2,
	/* max         */ 127,
	/* maxlen      */ 0,
	/* enumptr     */ NULL,
	/* collptr     */ NULL,
	/* totextptr   */ p80211_totext_boundedint,
	/* fromtextptr */ p80211_fromtext_boundedint,
	/* validfunptr */ p80211_isvalid_boundedint
},
{
	/* name        */ MKITEMNAME("basicrate7"),
	/* did         */ P80211DID_MKID(0,0,0,0,0,0,P80211_TYPE_BOUNDEDINT),
	/* flags       */ P80211ITEM_SETFLAGS(0UL, ISREQUEST, 0UL),
	/* min         */ 2,
	/* max         */ 127,
	/* maxlen      */ 0,
	/* enumptr     */ NULL,
	/* collptr     */ NULL,
	/* totextptr   */ p80211_totext_boundedint,
	/* fromtextptr */ p80211_fromtext_boundedint,
	/* validfunptr */ p80211_isvalid_boundedint
},
{
	/* name        */ MKITEMNAME("basicrate8"),
	/* did         */ P80211DID_MKID(0,0,0,0,0,0,P80211_TYPE_BOUNDEDINT),
	/* flags       */ P80211ITEM_SETFLAGS(0UL, ISREQUEST, 0UL),
	/* min         */ 2,
	/* max         */ 127,
	/* maxlen      */ 0,
	/* enumptr     */ NULL,
	/* collptr     */ NULL,
	/* totextptr   */ p80211_totext_boundedint,
	/* fromtextptr */ p80211_fromtext_boundedint,
	/* validfunptr */ p80211_isvalid_boundedint
},
{
	/* name        */ MKITEMNAME("operationalrate1"),
	/* did         */ P80211DID_MKID(0,0,0,0,0,0,P80211_TYPE_BOUNDEDINT),
	/* flags       */ P80211ITEM_SETFLAGS(ISREQUIRED, ISREQUEST, 0UL),
	/* min         */ 2,
	/* max         */ 127,
	/* maxlen      */ 0,
	/* enumptr     */ NULL,
	/* collptr     */ NULL,
	/* totextptr   */ p80211_totext_boundedint,
	/* fromtextptr */ p80211_fromtext_boundedint,
	/* validfunptr */ p80211_isvalid_boundedint
},
{
	/* name        */ MKITEMNAME("operationalrate2"),
	/* did         */ P80211DID_MKID(0,0,0,0,0,0,P80211_TYPE_BOUNDEDINT),
	/* flags       */ P80211ITEM_SETFLAGS(0UL, ISREQUEST, 0UL),
	/* min         */ 2,
	/* max         */ 127,
	/* maxlen      */ 0,
	/* enumptr     */ NULL,
	/* collptr     */ NULL,
	/* totextptr   */ p80211_totext_boundedint,
	/* fromtextptr */ p80211_fromtext_boundedint,
	/* validfunptr */ p80211_isvalid_boundedint
},
{
	/* name        */ MKITEMNAME("operationalrate3"),
	/* did         */ P80211DID_MKID(0,0,0,0,0,0,P80211_TYPE_BOUNDEDINT),
	/* flags       */ P80211ITEM_SETFLAGS(0UL, ISREQUEST, 0UL),
	/* min         */ 2,
	/* max         */ 127,
	/* maxlen      */ 0,
	/* enumptr     */ NULL,
	/* collptr     */ NULL,
	/* totextptr   */ p80211_totext_boundedint,
	/* fromtextptr */ p80211_fromtext_boundedint,
	/* validfunptr */ p80211_isvalid_boundedint
},
{
	/* name        */ MKITEMNAME("operationalrate4"),
	/* did         */ P80211DID_MKID(0,0,0,0,0,0,P80211_TYPE_BOUNDEDINT),
	/* flags       */ P80211ITEM_SETFLAGS(0UL, ISREQUEST, 0UL),
	/* min         */ 2,
	/* max         */ 127,
	/* maxlen      */ 0,
	/* enumptr     */ NULL,
	/* collptr     */ NULL,
	/* totextptr   */ p80211_totext_boundedint,
	/* fromtextptr */ p80211_fromtext_boundedint,
	/* validfunptr */ p80211_isvalid_boundedint
},
{
	/* name        */ MKITEMNAME("operationalrate5"),
	/* did         */ P80211DID_MKID(0,0,0,0,0,0,P80211_TYPE_BOUNDEDINT),
	/* flags       */ P80211ITEM_SETFLAGS(0UL, ISREQUEST, 0UL),
	/* min         */ 2,
	/* max         */ 127,
	/* maxlen      */ 0,
	/* enumptr     */ NULL,
	/* collptr     */ NULL,
	/* totextptr   */ p80211_totext_boundedint,
	/* fromtextptr */ p80211_fromtext_boundedint,
	/* validfunptr */ p80211_isvalid_boundedint
},
{
	/* name        */ MKITEMNAME("operationalrate6"),
	/* did         */ P80211DID_MKID(0,0,0,0,0,0,P80211_TYPE_BOUNDEDINT),
	/* flags       */ P80211ITEM_SETFLAGS(0UL, ISREQUEST, 0UL),
	/* min         */ 2,
	/* max         */ 127,
	/* maxlen      */ 0,
	/* enumptr     */ NULL,
	/* collptr     */ NULL,
	/* totextptr   */ p80211_totext_boundedint,
	/* fromtextptr */ p80211_fromtext_boundedint,
	/* validfunptr */ p80211_isvalid_boundedint
},
{
	/* name        */ MKITEMNAME("operationalrate7"),
	/* did         */ P80211DID_MKID(0,0,0,0,0,0,P80211_TYPE_BOUNDEDINT),
	/* flags       */ P80211ITEM_SETFLAGS(0UL, ISREQUEST, 0UL),
	/* min         */ 2,
	/* max         */ 127,
	/* maxlen      */ 0,
	/* enumptr     */ NULL,
	/* collptr     */ NULL,
	/* totextptr   */ p80211_totext_boundedint,
	/* fromtextptr */ p80211_fromtext_boundedint,
	/* validfunptr */ p80211_isvalid_boundedint
},
{
	/* name        */ MKITEMNAME("operationalrate8"),
	/* did         */ P80211DID_MKID(0,0,0,0,0,0,P80211_TYPE_BOUNDEDINT),
	/* flags       */ P80211ITEM_SETFLAGS(0UL, ISREQUEST, 0UL),
	/* min         */ 2,
	/* max         */ 127,
	/* maxlen      */ 0,
	/* enumptr     */ NULL,
	/* collptr     */ NULL,
	/* totextptr   */ p80211_totext_boundedint,
	/* fromtextptr */ p80211_fromtext_boundedint,
	/* validfunptr */ p80211_isvalid_boundedint
},
{
	/* name        */ MKITEMNAME("resultcode"),
	/* did         */ P80211DID_MKID(0,0,0,0,0,0,P80211_TYPE_ENUMINT),
	/* flags       */ P80211ITEM_SETFLAGS(ISREQUIRED, 0UL, ISCONFIRM),
	/* min         */ 0,
	/* max         */ 0,
	/* maxlen      */ 0,
	/* enumptr     */ &MKENUMNAME(resultcode),
	/* collptr     */ NULL,
	/* totextptr   */ p80211_totext_enumint,
	/* fromtextptr */ p80211_fromtext_enumint,
	/* validfunptr */ p80211_isvalid_enumint
}
};  /* end of start request message metadata list */

UINT32	MKREQMETASIZE(start) = 
		sizeof(MKREQMETANAME(start))/sizeof(p80211meta_t);

/*--------------------------------------------------------------------*/
/* metadata for the authenticate indication message arguments */

extern	UINT32	MKINDMETASIZE(authenticate);

p80211meta_t MKINDMETANAME(authenticate)[] = {
{
	/* name        */ (char *)&(MKINDMETASIZE(authenticate)),
	/* did         */ 0,
	/* flags       */ 0,
	/* min         */ 0,
	/* max         */ 0,
	/* maxlen      */ 0,
	/* enumptr     */ NULL,
	/* collptr     */ NULL,
	/* totextptr   */ NULL,
	/* fromtextptr */ NULL,
	/* validfunptr */ NULL
},
{
	/* name        */ "peerstaaddress",
	/* did         */ P80211DID_MKID(0,0,0,0,0,0,P80211_TYPE_OCTETSTR),
	/* flags       */ P80211ITEM_SETFLAGS(ISREQUIRED, ISREQUEST, ISCONFIRM),
	/* min         */ 0,
	/* max         */ 0,
	/* maxlen      */ MAXLEN_PSTR6,
	/* enumptr     */ NULL,
	/* collptr     */ NULL,
	/* totextptr   */ p80211_totext_octetstr,
	/* fromtextptr */ p80211_fromtext_octetstr,
	/* validfunptr */ p80211_isvalid_octetstr
},
{
	/* name        */ MKITEMNAME("authenticationtype"),
	/* did         */ P80211DID_MKID(0,0,0,0,0,0,P80211_TYPE_ENUMINT),
	/* flags       */ P80211ITEM_SETFLAGS(ISREQUIRED, ISREQUEST, ISCONFIRM),
	/* min         */ 0,
	/* max         */ 0,
	/* maxlen      */ 0,
	/* enumptr     */ &MKENUMNAME(authalg),
	/* collptr     */ NULL,
	/* totextptr   */ p80211_totext_enumint,
	/* fromtextptr */ p80211_fromtext_enumint,
	/* validfunptr */ p80211_isvalid_enumint
}
};  /* end of authenticate indication metadata list */

UINT32	MKINDMETASIZE(authenticate) = 
		sizeof(MKINDMETANAME(authenticate))/sizeof(p80211meta_t);

/*--------------------------------------------------------------------*/
/* metadata for the authenticate indication message arguments */

extern	UINT32	MKINDMETASIZE(deauthenticate);

p80211meta_t MKINDMETANAME(deauthenticate)[] = {
{
	/* name        */ (char *)&(MKINDMETASIZE(deauthenticate)),
	/* did         */ 0,
	/* flags       */ 0,
	/* min         */ 0,
	/* max         */ 0,
	/* maxlen      */ 0,
	/* enumptr     */ NULL,
	/* collptr     */ NULL,
	/* totextptr   */ NULL,
	/* fromtextptr */ NULL,
	/* validfunptr */ NULL
},
{
	/* name        */ "peerstaaddress",
	/* did         */ P80211DID_MKID(0,0,0,0,0,0,P80211_TYPE_OCTETSTR),
	/* flags       */ P80211ITEM_SETFLAGS(ISREQUIRED, ISREQUEST, ISCONFIRM),
	/* min         */ 0,
	/* max         */ 0,
	/* maxlen      */ MAXLEN_PSTR6,
	/* enumptr     */ NULL,
	/* collptr     */ NULL,
	/* totextptr   */ p80211_totext_octetstr,
	/* fromtextptr */ p80211_fromtext_octetstr,
	/* validfunptr */ p80211_isvalid_octetstr
},
{
	/* name        */ MKITEMNAME("reasoncode"),
	/* did         */ P80211DID_MKID(0,0,0,0,0,0,P80211_TYPE_ENUMINT),
	/* flags       */ P80211ITEM_SETFLAGS(ISREQUIRED, ISREQUEST, 0UL),
	/* min         */ 0,
	/* max         */ 0,
	/* maxlen      */ 0,
	/* enumptr     */ &MKENUMNAME(reason),
	/* collptr     */ NULL,
	/* totextptr   */ p80211_totext_enumint,
	/* fromtextptr */ p80211_fromtext_enumint,
	/* validfunptr */ p80211_isvalid_enumint
}
};  /* end of deauthenticate indication metadata list */

UINT32	MKINDMETASIZE(deauthenticate) = 
		sizeof(MKINDMETANAME(deauthenticate))/sizeof(p80211meta_t);

/*--------------------------------------------------------------------*/
/* metadata for the associate indication message arguments */

extern	UINT32	MKINDMETASIZE(associate);

p80211meta_t MKINDMETANAME(associate)[] = {
{
	/* name        */ (char *)&(MKINDMETASIZE(associate)),
	/* did         */ 0,
	/* flags       */ 0,
	/* min         */ 0,
	/* max         */ 0,
	/* maxlen      */ 0,
	/* enumptr     */ NULL,
	/* collptr     */ NULL,
	/* totextptr   */ NULL,
	/* fromtextptr */ NULL,
	/* validfunptr */ NULL
},
{
	/* name        */ "peerstaaddress",
	/* did         */ P80211DID_MKID(0,0,0,0,0,0,P80211_TYPE_OCTETSTR),
	/* flags       */ P80211ITEM_SETFLAGS(ISREQUIRED, ISREQUEST, 0UL),
	/* min         */ 0,
	/* max         */ 0,
	/* maxlen      */ MAXLEN_PSTR6,
	/* enumptr     */ NULL,
	/* collptr     */ NULL,
	/* totextptr   */ p80211_totext_octetstr,
	/* fromtextptr */ p80211_fromtext_octetstr,
	/* validfunptr */ p80211_isvalid_octetstr
}
};  /* end of associate indication metadata list */

UINT32	MKINDMETASIZE(associate) =
		sizeof(MKINDMETANAME(associate))/sizeof(p80211meta_t);

/*--------------------------------------------------------------------*/
/* metadata for the reassociate indication message arguments */

extern	UINT32	MKINDMETASIZE(reassociate);

p80211meta_t MKINDMETANAME(reassociate)[] = {
{
	/* name        */ (char *)&(MKINDMETASIZE(reassociate)),
	/* did         */ 0,
	/* flags       */ 0,
	/* min         */ 0,
	/* max         */ 0,
	/* maxlen      */ 0,
	/* enumptr     */ NULL,
	/* collptr     */ NULL,
	/* totextptr   */ NULL,
	/* fromtextptr */ NULL,
	/* validfunptr */ NULL
},
{
	/* name        */ "peerstaaddress",
	/* did         */ P80211DID_MKID(0,0,0,0,0,0,P80211_TYPE_OCTETSTR),
	/* flags       */ P80211ITEM_SETFLAGS(ISREQUIRED, ISREQUEST, 0UL),
	/* min         */ 0,
	/* max         */ 0,
	/* maxlen      */ MAXLEN_PSTR6,
	/* enumptr     */ NULL,
	/* collptr     */ NULL,
	/* totextptr   */ p80211_totext_octetstr,
	/* fromtextptr */ p80211_fromtext_octetstr,
	/* validfunptr */ p80211_isvalid_octetstr
}
};  /* end of reassociate indication metadata list */

UINT32	MKINDMETASIZE(reassociate) = 
		sizeof(MKINDMETANAME(reassociate))/sizeof(p80211meta_t);

/*--------------------------------------------------------------------*/
/* metadata for the disassociate indication message arguments */

extern	UINT32	MKINDMETASIZE(disassociate);

p80211meta_t MKINDMETANAME(disassociate)[] = {
{
	/* name        */ (char *)&(MKINDMETASIZE(disassociate)),
	/* did         */ 0,
	/* flags       */ 0,
	/* min         */ 0,
	/* max         */ 0,
	/* maxlen      */ 0,
	/* enumptr     */ NULL,
	/* collptr     */ NULL,
	/* totextptr   */ NULL,
	/* fromtextptr */ NULL,
	/* validfunptr */ NULL
},
{
	/* name        */ "peerstaaddress",
	/* did         */ P80211DID_MKID(0,0,0,0,0,0,P80211_TYPE_OCTETSTR),
	/* flags       */ P80211ITEM_SETFLAGS(ISREQUIRED, ISREQUEST, ISCONFIRM),
	/* min         */ 0,
	/* max         */ 0,
	/* maxlen      */ MAXLEN_PSTR6,
	/* enumptr     */ NULL,
	/* collptr     */ NULL,
	/* totextptr   */ p80211_totext_octetstr,
	/* fromtextptr */ p80211_fromtext_octetstr,
	/* validfunptr */ p80211_isvalid_octetstr
},
{
	/* name        */ MKITEMNAME("reasoncode"),
	/* did         */ P80211DID_MKID(0,0,0,0,0,0,P80211_TYPE_ENUMINT),
	/* flags       */ P80211ITEM_SETFLAGS(ISREQUIRED, ISREQUEST, 0UL),
	/* min         */ 0,
	/* max         */ 0,
	/* maxlen      */ 0,
	/* enumptr     */ &MKENUMNAME(reason),
	/* collptr     */ NULL,
	/* totextptr   */ p80211_totext_enumint,
	/* fromtextptr */ p80211_fromtext_enumint,
	/* validfunptr */ p80211_isvalid_enumint
}
};  /* end of disassociate indication metadata list */

UINT32	MKINDMETASIZE(disassociate) = sizeof(MKINDMETANAME(disassociate))/sizeof(p80211meta_t);


/*--------------------------------------------------------------------*/
/* Messages Group array */
/*  Note: the positions in this array are _very_ important.  They  */
/*        match the message codes #defined in p80211msg.h . */


extern UINT32 MKGRPMETASIZE(dot11req);

grplistitem_t MKGRPMETANAME(dot11req)[] = {
	{
		(char *)&MKGRPMETASIZE(dot11req),
		NULL
	},
	{
		"mibget",
		MKREQMETANAME(mibget)
	},
	{
		"mibset",
		MKREQMETANAME(mibset)
	},
	{
		"powermgmt",
		MKREQMETANAME(powermgmt)
	},
	{
		"scan",
		MKREQMETANAME(scan)
	},
	{
		"scan_results",
		MKREQMETANAME(scan_results)
	},
	{
		"join",
		MKREQMETANAME(join)
	},
	{
		"authenticate",
		MKREQMETANAME(authenticate)
	},
	{
		"deauthenticate",
		MKREQMETANAME(deauthenticate)
	},
	{
		"associate",
		MKREQMETANAME(associate)
	},
	{
		"reassociate",
		MKREQMETANAME(reassociate)
	},
	{
		"disassociate",
		MKREQMETANAME(disassociate)
	},
	{
		"start",
		MKREQMETANAME(start)
	}
};

UINT32 MKGRPMETASIZE(dot11req) =sizeof(MKGRPMETANAME(dot11req)) /
				sizeof(grplistitem_t);

extern UINT32 MKGRPMETASIZE(dot11ind);

grplistitem_t MKGRPMETANAME(dot11ind)[] = {
	{
		(char *)&MKGRPMETASIZE(dot11ind),
		NULL
	},
	{
		"authenticate",
		MKINDMETANAME(authenticate)
	},
	{
		"deauthenticate",
		MKINDMETANAME(deauthenticate)
	},
	{
		"associate",
		MKINDMETANAME(associate)
	},
	{
		"reassociate",
		MKINDMETANAME(reassociate)
	},
	{
		"disassociate",
		MKINDMETANAME(disassociate)
	}
};

UINT32 MKGRPMETASIZE(dot11ind) =sizeof(MKGRPMETANAME(dot11ind)) /
				sizeof(grplistitem_t);


extern UINT32 msg_catlist_size;

catlistitem_t msg_catlist[] =
{
	{
		(char *)&msg_catlist_size,
		NULL
	},
	{
		"dot11req",
		MKGRPMETANAME(dot11req)
	},
	{
		"dot11ind",
		MKGRPMETANAME(dot11ind)
	}
	/* dot11cfm does not exist at this time */
};

UINT32 msg_catlist_size = sizeof(msg_catlist)/sizeof(catlistitem_t);


/*================================================================*/
/* Local Function Declarations */


/*================================================================*/
/* Function Definitions */

/*----------------------------------------------------------------
* p80211item_getoffset
*
*   Returns the offset of the data item identified by a given DID.
*   This function assumes a valid did is passed to the function.  
*
* Arguments:
*	did	a valid, complete DID
*
* Returns: 
*	0xffffffff	if the type from the did doesn't match a 
*			known type
*	offset		on success
----------------------------------------------------------------*/
UINT32 p80211item_getoffset( catlistitem_t *metalist, UINT32 did )
{
	UINT32			offset;
	UINT32			item;
	INT			i;
	p80211meta_t 		*alist=NULL;

	offset = 0UL;

	if ( (p80211_isvalid_did(metalist, did )) != P80211DID_INVALID ) {
		alist = metalist[P80211DID_SECTION(did)].
			grplist[P80211DID_GROUP(did)].itemlist;
		item = P80211DID_ITEM(did);

		for ( i = 1; i < item; i++ ) {
			/* when generating the offset, 8 is added to the
			data len which represents the size of the did and
			the len of each data item triple */
			switch( P80211DID_TYPE(alist[i].did) ) {
			case P80211_TYPE_OCTETSTR:
			case P80211_TYPE_DISPLAYSTR:
				/* add one for the pstr length byte */
				offset += (8UL + alist[i].maxlen + 1UL);
				break;

			case P80211_TYPE_INT:
			case P80211_TYPE_BOUNDEDINT:
			case P80211_TYPE_ENUMINT:
				/* all int types are 4 bytes */
				offset += 12UL;
				break;
			case P80211_TYPE_UNKDATA:
				offset += (8UL + alist[i].maxlen);
				break;
			default:
				printf("Unknown data type of %lu\n",
					P80211DID_TYPE(alist[i].did) );
				offset = 0xffffffff;
				break;
			}
		} /* for each arg meta data item */
	} else {
		offset = 0xffffffff;
	}

	return offset;
}
