/*  help.c: wlanctl help messages
* --------------------------------------------------------------------
*
* Linux WLAN 
*
* The contents of this file are subject to the Mozilla Public
* License Version 1.0 (the "License"); you may not use this file
* except in compliance with the License. You may obtain a copy of
* the License at http://www.mozilla.org/MPL/
*
* Software distributed under the License is distributed on an "AS
* IS" basis, WITHOUT WARRANTY OF ANY KIND, either express or
* implied. See the License for the specific language governing
* rights and limitations under the License.
*
* The initial developers of the original code are Jo-Ellen F. Mathews
* <joellen@absoval.com> and Mark S. Mathews <mark@absoval.com>.  
* Portions created by Jo-Ellen F. and Mark S. Mathews
* are Copyright (C) 1998 AbsoluteValue Software, Inc.  All Rights Reserved.
*   
* --------------------------------------------------------------------
*
* The initial authors may be reached at info@absoval.com, or 
* C/O AbsoluteValue Software Inc., P.O. Box 941149, 
* Maitland, FL, 32794-1149
*
* --------------------------------------------------------------------
*
* --------------------------------------------------------------------
*/

/*================================================================*/
/* System Includes */

#include <stdlib.h>
#include <stdio.h>
#include <string.h>

/*================================================================*/
/* Project Includes */

#include <wlan/wlan_compat.h>
#include <wlan/version.h>
#include <wlan/p80211types.h>
#include <wlan/p80211meta.h>
#include <wlan/p80211metamsg.h>
#include <wlan/p80211msg.h>

/*================================================================*/
/* Local Constants */


/*================================================================*/
/* Local Macros */


/*================================================================*/
/* Local Types */


/*================================================================*/
/* Local Static Definitions */


/*================================================================*/
/* Local Function Declarations */

void	usage(void);
void	print_allrequests(void);			

/*================================================================*/
/* Function Definitions */


/*----------------------------------------------------------------
* usage
*
* Print a short usage message
*
* Arguments:
*	none
*
* Returns: 
*	nothing
----------------------------------------------------------------*/
void usage(void)
{
	printf("wlanctl: - control utility for 802.11 devices\n");
	printf("  usage: wlanctl interface|version|commands cmd cmdarg [cmdarg...]\n\n");

	printf("         where \"interface\" is the name of a wireless\n");
	printf("         network interface.  Running \'ifconfig\' will list\n");
	printf("         all network interfaces.\n\n");

	printf("         Refer to the wlanctl man page or run \n");
	printf("         \'wlanctl commands\' for more details\n\n");
}


/*----------------------------------------------------------------
* print_allrequests
*
* Traverse all of the requests in the message and message argument 
* metadata.  Print the name of the request, the name of each request
* argument and any validation requirements.
*
* Arguments:
*	none
*
* Returns: 
*	nothing
----------------------------------------------------------------*/
void print_allrequests(void)
{
	int		i;
	int		j;
	int		k;
	UINT32		did;
	p80211meta_t	*request;
	grplistitem_t	*grp;
	int		nargs;
	int		ncmds;
	p80211enum_t	*enump;


	ncmds = GETMETASIZE(msg_catlist[P80211SEC_DOT11REQ].grplist);

	for (i = 1; i < ncmds; i++) { 
		did = P80211DID_MKSECTION(P80211SEC_DOT11REQ) | P80211DID_MKGROUP(i);
		if ( (grp = p80211_did2grp(msg_catlist, did)) != NULL ) {

			printf("Command: %s\n", grp->name);
			request = grp->itemlist;
			nargs = GETMETASIZE(request);

			for ( j = 1; j < nargs; j++)
			{
				if  ( P80211ITEM_ISREQUEST(request[j].flags) ) {

					printf( "    %s(%s):",
					request[j].name,
					P80211ITEM_ISREQUIRED(request[j].flags) ?
						"required" :  "optional");

					switch (P80211DID_TYPE(request[j].did)) {
					case P80211_TYPE_OCTETSTR:
						printf("OCTETSTR{");
						printf("maxlen=%ld}", request[j].maxlen);
						break;
					case P80211_TYPE_DISPLAYSTR:
						printf("DISPLAYSTR{");
						printf("maxlen=%ld}", request[j].maxlen);
						break;
					case P80211_TYPE_BOUNDEDINT:
						printf("BOUNDEDINT{");
						printf("min=%ld, max=%ld}", 
						request[j].min,
						request[j].max);
						break;
					case P80211_TYPE_INT:
						printf("INT");
						break;
					case P80211_TYPE_ENUMINT:
						printf("ENUMINT{");
						enump = request[j].enumptr;
						for ( k = 0; k < enump->nitems; k++){
							printf("%s", enump->list[k].name);
							if ( k < enump->nitems - 1) {
								printf("|");
							}
						}
						printf("}");
						break;
					case P80211_TYPE_UNKDATA:
						printf("UNKDATA");
						break;
					default:
						printf("ERROR: unknown type!\n");
						break;
					}
					printf("\n");
				}
			}
		}
		else {
			printf("help.c: invalid group did\n");
		}
	}
}




